/* This file is a copy of the default theme CSS from the mkdocs-material
   where we reset the font-size to 100% instead of 125% and adjust the font-sizes
   based on this (ie, multiply them by 1.25).

   This is because our React-rendered components expect the font-size to be 100%,
   and defined their sizes in rem units which we cannot change for the components only.

   As a replacement, we should investiguate encapsulating the components styling with
   a shadow DOM + finding how to attach style sheets imported via webpack css loader
   to the shadow DOM. Maybe something in the style of
   https://ryanschiang.com/react-shadow-dom-css-modules ?
 */

@charset "UTF-8";html {
    -webkit-text-size-adjust: none;
    -moz-text-size-adjust: none;
    text-size-adjust: none;
    box-sizing: border-box
}

*,:after,:before {
    box-sizing: inherit
}

@media (prefers-reduced-motion) {
    *,:after,:before {
        transition: none!important
    }
}

body {
    margin: 0
}

a,button,input,label {
    -webkit-tap-highlight-color: transparent
}

a {
    color: inherit;
    text-decoration: none
}

hr {
    border: 0;
    box-sizing: initial;
    display: block;
    height: 0.0625rem;
    overflow: visible;
    padding: 0
}

small {
    font-size: 80%
}

sub,sup {
    line-height: 1em
}

img {
    border-style: none
}

table {
    border-collapse: initial;
    border-spacing: 0
}

td,th {
    font-weight: 400;
    vertical-align: top
}

button {
    background: #0000;
    border: 0;
    font-family: inherit;
    font-size: inherit;
    margin: 0;
    padding: 0
}

input {
    border: 0;
    outline: none
}

:root {
    --md-primary-fg-color: #4051b5;
    --md-primary-fg-color--light: #5d6cc0;
    --md-primary-fg-color--dark: #303fa1;
    --md-primary-bg-color: #fff;
    --md-primary-bg-color--light: #ffffffb3;
    --md-accent-fg-color: #526cfe;
    --md-accent-fg-color--transparent: #526cfe1a;
    --md-accent-bg-color: #fff;
    --md-accent-bg-color--light: #ffffffb3
}

[data-md-color-scheme=default] {
    color-scheme: light
}

[data-md-color-scheme=default] img[src$="#gh-dark-mode-only"],[data-md-color-scheme=default] img[src$="#only-dark"] {
    display: none
}

:root,[data-md-color-scheme=default] {
    --md-default-fg-color: #000000de;
    --md-default-fg-color--light: #0000008a;
    --md-default-fg-color--lighter: #00000052;
    --md-default-fg-color--lightest: #00000012;
    --md-default-bg-color: #fff;
    --md-default-bg-color--light: #ffffffb3;
    --md-default-bg-color--lighter: #ffffff4d;
    --md-default-bg-color--lightest: #ffffff1f;
    --md-code-fg-color: #36464e;
    --md-code-bg-color: #f5f5f5;
    --md-code-hl-color: #ffff0080;
    --md-code-hl-number-color: #d52a2a;
    --md-code-hl-special-color: #db1457;
    --md-code-hl-function-color: #a846b9;
    --md-code-hl-constant-color: #6e59d9;
    --md-code-hl-keyword-color: #3f6ec6;
    --md-code-hl-string-color: #1c7d4d;
    --md-code-hl-name-color: var(--md-code-fg-color);
    --md-code-hl-operator-color: var(--md-default-fg-color--light);
    --md-code-hl-punctuation-color: var(--md-default-fg-color--light);
    --md-code-hl-comment-color: var(--md-default-fg-color--light);
    --md-code-hl-generic-color: var(--md-default-fg-color--light);
    --md-code-hl-variable-color: var(--md-default-fg-color--light);
    --md-typeset-color: var(--md-default-fg-color);
    --md-typeset-a-color: var(--md-primary-fg-color);
    --md-typeset-mark-color: #ffff0080;
    --md-typeset-del-color: #f5503d26;
    --md-typeset-ins-color: #0bd57026;
    --md-typeset-kbd-color: #fafafa;
    --md-typeset-kbd-accent-color: #fff;
    --md-typeset-kbd-border-color: #b8b8b8;
    --md-typeset-table-color: #0000001f;
    --md-typeset-table-color--light: rgba(0,0,0,.035);
    --md-admonition-fg-color: var(--md-default-fg-color);
    --md-admonition-bg-color: var(--md-default-bg-color);
    --md-warning-fg-color: #000000de;
    --md-warning-bg-color: #ff9;
    --md-footer-fg-color: #fff;
    --md-footer-fg-color--light: #ffffffb3;
    --md-footer-fg-color--lighter: #ffffff73;
    --md-footer-bg-color: #000000de;
    --md-footer-bg-color--dark: #00000052;
    --md-shadow-z1: 0 0.25rem 0.625rem #0000000d,0 0 0.0625rem #0000001a;
    --md-shadow-z2: 0 0.25rem 0.625rem #0000001a,0 0 0.0625rem #00000040;
    --md-shadow-z3: 0 0.25rem 0.625rem #0003,0 0 0.0625rem #00000059
}

.md-icon svg {
    fill: currentcolor;
    display: block;
    height: 1.5rem;
    width: 1.5rem
}

body {
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    --md-text-font-family: var(--md-text-font,_),-apple-system,BlinkMacSystemFont,Helvetica,Arial,sans-serif;
    --md-code-font-family: var(--md-code-font,_),SFMono-Regular,Consolas,Menlo,monospace
}

aside,body,input {
    font-feature-settings: "kern","liga";
    color: var(--md-typeset-color);
    font-family: var(--md-text-font-family)
}

code,kbd,pre {
    font-feature-settings: "kern";
    font-family: var(--md-code-font-family)
}

:root {
    --md-typeset-table-sort-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="m18 21-4-4h3V7h-3l4-4 4 4h-3v10h3M2 19v-2h10v2M2 13v-2h7v2M2 7V5h4v2H2Z"/></svg>');
    --md-typeset-table-sort-icon--asc: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M19 17h3l-4 4-4-4h3V3h2M2 17h10v2H2M6 5v2H2V5m0 6h7v2H2v-2Z"/></svg>');
    --md-typeset-table-sort-icon--desc: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M19 7h3l-4-4-4 4h3v14h2M2 17h10v2H2M6 5v2H2V5m0 6h7v2H2v-2Z"/></svg>')
}

.md-typeset {
    -webkit-print-color-adjust: exact;
    color-adjust: exact;
    font-size: 1rem;
    line-height: 1.6
}

@media print {
    .md-typeset {
        font-size: 0.8500000000000001rem
    }
}

.md-typeset blockquote,.md-typeset dl,.md-typeset figure,.md-typeset ol,.md-typeset pre,.md-typeset ul {
    margin-bottom: 1em;
    margin-top: 1em
}

.md-typeset h1 {
    color: var(--md-default-fg-color--light);
    font-size: 2em;
    line-height: 1.3;
    margin: 0 0 1.25em
}

.md-typeset h1,.md-typeset h2 {
    font-weight: 300;
    letter-spacing: -.01em
}

.md-typeset h2 {
    font-size: 1.5625em;
    line-height: 1.4;
    margin: 1.6em 0 .64em
}

.md-typeset h3 {
    font-size: 1.25em;
    font-weight: 400;
    letter-spacing: -.01em;
    line-height: 1.5;
    margin: 1.6em 0 .8em
}

.md-typeset h2+h3 {
    margin-top: .8em
}

.md-typeset h4 {
    font-weight: 700;
    letter-spacing: -.01em;
    margin: 1em 0
}

.md-typeset h5,.md-typeset h6 {
    color: var(--md-default-fg-color--light);
    font-size: .8em;
    font-weight: 700;
    letter-spacing: -.01em;
    margin: 1.25em 0
}

.md-typeset h5 {
    text-transform: uppercase
}

.md-typeset hr {
    border-bottom: 0.0625rem solid var(--md-default-fg-color--lightest);
    display: flow-root;
    margin: 1.5em 0
}

.md-typeset a {
    color: var(--md-typeset-a-color);
    word-break: break-word
}

.md-typeset a,.md-typeset a:before {
    transition: color 125ms
}

.md-typeset a:focus,.md-typeset a:hover {
    color: var(--md-accent-fg-color)
}

.md-typeset a:focus code,.md-typeset a:hover code {
    background-color: var(--md-accent-fg-color--transparent)
}

.md-typeset a code {
    color: currentcolor;
    transition: background-color 125ms
}

.md-typeset a.focus-visible {
    outline-color: var(--md-accent-fg-color);
    outline-offset: 0.25rem
}

.md-typeset code,.md-typeset kbd,.md-typeset pre {
    color: var(--md-code-fg-color);
    direction: ltr;
    font-variant-ligatures: none
}

@media print {
    .md-typeset code,.md-typeset kbd,.md-typeset pre {
        white-space: pre-wrap
    }
}

.md-typeset code {
    background-color: var(--md-code-bg-color);
    border-radius: 0.125rem;
    -webkit-box-decoration-break: clone;
    box-decoration-break: clone;
    font-size: .85em;
    padding: 0 .2941176471em;
    word-break: break-word
}

.md-typeset code:not(.focus-visible) {
    -webkit-tap-highlight-color: transparent;
    outline: none
}

.md-typeset pre {
    display: flow-root;
    line-height: 1.4;
    position: relative
}

.md-typeset pre>code {
    -webkit-box-decoration-break: slice;
    box-decoration-break: slice;
    box-shadow: none;
    display: block;
    margin: 0;
    outline-color: var(--md-accent-fg-color);
    overflow: auto;
    padding: .7720588235em 1.1764705882em;
    scrollbar-color: var(--md-default-fg-color--lighter) #0000;
    scrollbar-width: thin;
    touch-action: auto;
    word-break: normal
}

.md-typeset pre>code:hover {
    scrollbar-color: var(--md-accent-fg-color) #0000
}

.md-typeset pre>code::-webkit-scrollbar {
    height: 0.25rem;
    width: 0.25rem
}

.md-typeset pre>code::-webkit-scrollbar-thumb {
    background-color: var(--md-default-fg-color--lighter)
}

.md-typeset pre>code::-webkit-scrollbar-thumb:hover {
    background-color: var(--md-accent-fg-color)
}

.md-typeset kbd {
    background-color: var(--md-typeset-kbd-color);
    border-radius: 0.125rem;
    box-shadow: 0 0.125rem 0 0.0625rem var(--md-typeset-kbd-border-color),0 0.125rem 0 var(--md-typeset-kbd-border-color),0 -0.125rem 0.25rem var(--md-typeset-kbd-accent-color) inset;
    color: var(--md-default-fg-color);
    display: inline-block;
    font-size: .75em;
    padding: 0 .6666666667em;
    vertical-align: text-top;
    word-break: break-word
}

.md-typeset mark {
    background-color: var(--md-typeset-mark-color);
    -webkit-box-decoration-break: clone;
    box-decoration-break: clone;
    color: inherit;
    word-break: break-word
}

.md-typeset abbr {
    border-bottom: 0.0625rem dotted var(--md-default-fg-color--light);
    cursor: help;
    text-decoration: none
}

@media (hover: none) {
    .md-typeset abbr[title]:focus:after,.md-typeset abbr[title]:hover:after {
        background-color:var(--md-default-fg-color);
        border-radius: 0.125rem;
        box-shadow: var(--md-shadow-z3);
        color: var(--md-default-bg-color);
        content: attr(title);
        font-size: 0.875rem;
        left: 1rem;
        margin-top: 2em;
        padding: 0.25rem 0.375rem;
        position: absolute;
        right: 1rem
    }
}

.md-typeset small {
    opacity: .75
}

[dir=ltr] .md-typeset sub,[dir=ltr] .md-typeset sup {
    margin-left: .078125em
}

[dir=rtl] .md-typeset sub,[dir=rtl] .md-typeset sup {
    margin-right: .078125em
}

[dir=ltr] .md-typeset blockquote {
    padding-left: 0.75rem
}

[dir=rtl] .md-typeset blockquote {
    padding-right: 0.75rem
}

[dir=ltr] .md-typeset blockquote {
    border-left: 0.25rem solid var(--md-default-fg-color--lighter)
}

[dir=rtl] .md-typeset blockquote {
    border-right: 0.25rem solid var(--md-default-fg-color--lighter)
}

.md-typeset blockquote {
    color: var(--md-default-fg-color--light);
    margin-left: 0;
    margin-right: 0
}

.md-typeset ul {
    list-style-type: disc
}

[dir=ltr] .md-typeset ol,[dir=ltr] .md-typeset ul {
    margin-left: .625em
}

[dir=rtl] .md-typeset ol,[dir=rtl] .md-typeset ul {
    margin-right: .625em
}

.md-typeset ol,.md-typeset ul {
    padding: 0
}

.md-typeset ol:not([hidden]),.md-typeset ul:not([hidden]) {
    display: flow-root
}

.md-typeset ol ol,.md-typeset ul ol {
    list-style-type: lower-alpha
}

.md-typeset ol ol ol,.md-typeset ul ol ol {
    list-style-type: lower-roman
}

[dir=ltr] .md-typeset ol li,[dir=ltr] .md-typeset ul li {
    margin-left: 1.25em
}

[dir=rtl] .md-typeset ol li,[dir=rtl] .md-typeset ul li {
    margin-right: 1.25em
}

.md-typeset ol li,.md-typeset ul li {
    margin-bottom: .5em
}

.md-typeset ol li blockquote,.md-typeset ol li p,.md-typeset ul li blockquote,.md-typeset ul li p {
    margin: .5em 0
}

.md-typeset ol li:last-child,.md-typeset ul li:last-child {
    margin-bottom: 0
}

[dir=ltr] .md-typeset ol li ol,[dir=ltr] .md-typeset ol li ul,[dir=ltr] .md-typeset ul li ol,[dir=ltr] .md-typeset ul li ul {
    margin-left: .625em
}

[dir=rtl] .md-typeset ol li ol,[dir=rtl] .md-typeset ol li ul,[dir=rtl] .md-typeset ul li ol,[dir=rtl] .md-typeset ul li ul {
    margin-right: .625em
}

.md-typeset ol li ol,.md-typeset ol li ul,.md-typeset ul li ol,.md-typeset ul li ul {
    margin-bottom: .5em;
    margin-top: .5em
}

[dir=ltr] .md-typeset dd {
    margin-left: 1.875em
}

[dir=rtl] .md-typeset dd {
    margin-right: 1.875em
}

.md-typeset dd {
    margin-bottom: 1.5em;
    margin-top: 1em
}

.md-typeset img,.md-typeset svg,.md-typeset video {
    height: auto;
    max-width: 100%
}

.md-typeset img[align=left] {
    margin: 1em 1em 1em 0
}

.md-typeset img[align=right] {
    margin: 1em 0 1em 1em
}

.md-typeset img[align]:only-child {
    margin-top: 0
}

.md-typeset figure {
    display: flow-root;
    margin: 1em auto;
    max-width: 100%;
    text-align: center;
    width: -webkit-fit-content;
    width: -moz-fit-content;
    width: fit-content
}

.md-typeset figure img {
    display: block
}

.md-typeset figcaption {
    font-style: italic;
    margin: 1em auto;
    max-width: 30rem
}

.md-typeset iframe {
    max-width: 100%
}

.md-typeset table:not([class]) {
    background-color: var(--md-default-bg-color);
    border: 0.0625rem solid var(--md-typeset-table-color);
    border-radius: 0.125rem;
    display: inline-block;
    font-size: 0.8rem;
    max-width: 100%;
    overflow: auto;
    touch-action: auto
}

@media print {
    .md-typeset table:not([class]) {
        display: table
    }
}

.md-typeset table:not([class])+* {
    margin-top: 1.5em
}

.md-typeset table:not([class]) td>:first-child,.md-typeset table:not([class]) th>:first-child {
    margin-top: 0
}

.md-typeset table:not([class]) td>:last-child,.md-typeset table:not([class]) th>:last-child {
    margin-bottom: 0
}

.md-typeset table:not([class]) td:not([align]),.md-typeset table:not([class]) th:not([align]) {
    text-align: left
}

[dir=rtl] .md-typeset table:not([class]) td:not([align]),[dir=rtl] .md-typeset table:not([class]) th:not([align]) {
    text-align: right
}

.md-typeset table:not([class]) th {
    font-weight: 700;
    min-width: 6.25rem;
    padding: .9375em 1.25em;
    vertical-align: top
}

.md-typeset table:not([class]) td {
    border-top: 0.0625rem solid var(--md-typeset-table-color);
    padding: .9375em 1.25em;
    vertical-align: top
}

.md-typeset table:not([class]) tbody tr {
    transition: background-color 125ms
}

.md-typeset table:not([class]) tbody tr:hover {
    background-color: var(--md-typeset-table-color--light);
    box-shadow: 0 0.0625rem 0 var(--md-default-bg-color) inset
}

.md-typeset table:not([class]) a {
    word-break: normal
}

.md-typeset table th[role=columnheader] {
    cursor: pointer
}

[dir=ltr] .md-typeset table th[role=columnheader]:after {
    margin-left: .5em
}

[dir=rtl] .md-typeset table th[role=columnheader]:after {
    margin-right: .5em
}

.md-typeset table th[role=columnheader]:after {
    content: "";
    display: inline-block;
    height: 1.2em;
    -webkit-mask-image: var(--md-typeset-table-sort-icon);
    mask-image: var(--md-typeset-table-sort-icon);
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    transition: background-color 125ms;
    vertical-align: text-bottom;
    width: 1.2em
}

.md-typeset table th[role=columnheader]:hover:after {
    background-color: var(--md-default-fg-color--lighter)
}

.md-typeset table th[role=columnheader][aria-sort=ascending]:after {
    background-color: var(--md-default-fg-color--light);
    -webkit-mask-image: var(--md-typeset-table-sort-icon--asc);
    mask-image: var(--md-typeset-table-sort-icon--asc)
}

.md-typeset table th[role=columnheader][aria-sort=descending]:after {
    background-color: var(--md-default-fg-color--light);
    -webkit-mask-image: var(--md-typeset-table-sort-icon--desc);
    mask-image: var(--md-typeset-table-sort-icon--desc)
}

.md-typeset__scrollwrap {
    margin: 1em -1rem;
    overflow-x: auto;
    touch-action: auto
}

.md-typeset__table {
    display: inline-block;
    margin-bottom: .5em;
    padding: 0 1rem
}

@media print {
    .md-typeset__table {
        display: block
    }
}

html .md-typeset__table table {
    display: table;
    margin: 0;
    overflow: hidden;
    width: 100%
}

@media screen and (max-width: 44.9375em) {
    .md-content__inner>pre {
        margin:1em -1rem
    }

    .md-content__inner>pre code {
        border-radius: 0
    }
}

.md-typeset .md-author {
    display: block;
    flex-shrink: 0;
    height: 2rem;
    overflow: hidden;
    position: relative;
    transition: color 125ms,transform 125ms;
    width: 2rem
}

.md-typeset .md-author img {
    border-radius: 100%;
    display: block
}

.md-typeset .md-author--more {
    background: var(--md-default-fg-color--lightest);
    color: var(--md-default-fg-color--lighter);
    font-size: 0.75rem;
    font-weight: 700;
    line-height: 2rem;
    text-align: center
}

.md-typeset .md-author--long {
    height: 3rem;
    width: 3rem
}

.md-typeset a.md-author {
    transform: scale(1)
}

.md-typeset a.md-author img {
    filter: grayscale(100%) opacity(75%);
    transition: filter 125ms
}

.md-typeset a.md-author:focus,.md-typeset a.md-author:hover {
    transform: scale(1.1);
    z-index: 1
}

.md-typeset a.md-author:focus img,.md-typeset a.md-author:hover img {
    filter: grayscale(0)
}

.md-banner {
    background-color: var(--md-footer-bg-color);
    color: var(--md-footer-fg-color);
    overflow: auto
}

@media print {
    .md-banner {
        display: none
    }
}

.md-banner--warning {
    background-color: var(--md-warning-bg-color);
    color: var(--md-warning-fg-color)
}

.md-banner__inner {
    font-size: 0.875rem;
    margin: 0.75rem auto;
    padding: 0 1rem
}

[dir=ltr] .md-banner__button {
    float: right
}

[dir=rtl] .md-banner__button {
    float: left
}

.md-banner__button {
    color: inherit;
    cursor: pointer;
    transition: opacity .25s
}

.no-js .md-banner__button {
    display: none
}

.md-banner__button:hover {
    opacity: .7
}

html {
    font-size: 100%;
    height: 100%;
    overflow-x: hidden
}

@media screen and (min-width: 100em) {
    html {
        font-size:137.5%
    }
}

@media screen and (min-width: 125em) {
    html {
        font-size:150%
    }
}

body {
    background-color: var(--md-default-bg-color);
    display: flex;
    flex-direction: column;
    font-size: 0.625rem;
    min-height: 100%;
    position: relative;
    width: 100%
}

@media print {
    body {
        display: block
    }
}

@media screen and (max-width: 59.9375em) {
    body[data-md-scrolllock] {
        position:fixed
    }
}

.md-grid {
    margin-left: auto;
    margin-right: auto;
    max-width: 76.25rem
}

.md-container {
    display: flex;
    flex-direction: column;
    flex-grow: 1
}

@media print {
    .md-container {
        display: block
    }
}

.md-main {
    flex-grow: 1
}

.md-main__inner {
    display: flex;
    height: 100%;
    margin-top: 1.875rem
}

.md-ellipsis {
    overflow: hidden;
    text-overflow: ellipsis
}

.md-toggle {
    display: none
}

.md-option {
    height: 0;
    opacity: 0;
    position: absolute;
    width: 0
}

.md-option:checked+label:not([hidden]) {
    display: block
}

.md-option.focus-visible+label {
    outline-color: var(--md-accent-fg-color);
    outline-style: auto
}

.md-skip {
    background-color: var(--md-default-fg-color);
    border-radius: 0.125rem;
    color: var(--md-default-bg-color);
    font-size: 0.8rem;
    margin: 0.625rem;
    opacity: 0;
    outline-color: var(--md-accent-fg-color);
    padding: 0.375rem 0.625rem;
    position: fixed;
    transform: translateY(0.5rem);
    z-index: -1
}

.md-skip:focus {
    opacity: 1;
    transform: translateY(0);
    transition: transform .25s cubic-bezier(.4,0,.2,1),opacity 175ms 75ms;
    z-index: 10
}

@page {
    margin: 25mm
}

:root {
    --md-clipboard-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M19 21H8V7h11m0-2H8a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h11a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2m-3-4H4a2 2 0 0 0-2 2v14h2V3h12V1Z"/></svg>')
}

.md-clipboard {
    border-radius: 0.125rem;
    color: var(--md-default-fg-color--lightest);
    cursor: pointer;
    height: 1.5em;
    outline-color: var(--md-accent-fg-color);
    outline-offset: 0.125rem;
    position: absolute;
    right: .5em;
    top: .5em;
    transition: color .25s;
    width: 1.5em;
    z-index: 1
}

@media print {
    .md-clipboard {
        display: none
    }
}

.md-clipboard:not(.focus-visible) {
    -webkit-tap-highlight-color: transparent;
    outline: none
}

:hover>.md-clipboard {
    color: var(--md-default-fg-color--light)
}

.md-clipboard:focus,.md-clipboard:hover {
    color: var(--md-accent-fg-color)
}

.md-clipboard:after {
    background-color: currentcolor;
    content: "";
    display: block;
    height: 1.125em;
    margin: 0 auto;
    -webkit-mask-image: var(--md-clipboard-icon);
    mask-image: var(--md-clipboard-icon);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    width: 1.125em
}

.md-clipboard--inline {
    cursor: pointer
}

.md-clipboard--inline code {
    transition: color .25s,background-color .25s
}

.md-clipboard--inline:focus code,.md-clipboard--inline:hover code {
    background-color: var(--md-accent-fg-color--transparent);
    color: var(--md-accent-fg-color)
}

@keyframes consent {
    0% {
        opacity: 0;
        transform: translateY(100%)
    }

    to {
        opacity: 1;
        transform: translateY(0)
    }
}

@keyframes overlay {
    0% {
        opacity: 0
    }

    to {
        opacity: 1
    }
}

.md-consent__overlay {
    animation: overlay .25s both;
    -webkit-backdrop-filter: blur(0.125rem);
    backdrop-filter: blur(0.125rem);
    background-color: #0000008a;
    height: 100%;
    opacity: 1;
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 5
}

.md-consent__inner {
    animation: consent .5s cubic-bezier(.1,.7,.1,1) both;
    background-color: var(--md-default-bg-color);
    border: 0;
    border-radius: 0.125rem;
    bottom: 0;
    box-shadow: 0 0 0.25rem #0000001a,0 0.25rem 0.5rem #0003;
    max-height: 100%;
    overflow: auto;
    padding: 0;
    position: fixed;
    width: 100%;
    z-index: 5
}

.md-consent__form {
    padding: 1rem
}

.md-consent__settings {
    display: none;
    margin: 1em 0
}

input:checked+.md-consent__settings {
    display: block
}

.md-consent__controls {
    margin-bottom: 1rem
}

.md-typeset .md-consent__controls .md-button {
    display: inline
}

@media screen and (max-width: 44.9375em) {
    .md-typeset .md-consent__controls .md-button {
        display:block;
        margin-top: 0.5rem;
        text-align: center;
        width: 100%
    }
}

.md-consent label {
    cursor: pointer
}

.md-content {
    flex-grow: 1;
    min-width: 0
}

.md-content__inner {
    margin: 0 1rem 1.5rem;
    padding-top: 0.75rem
}

@media screen and (min-width: 76.25em) {
    [dir=ltr] .md-sidebar--primary:not([hidden])~.md-content>.md-content__inner {
        margin-left:1.5rem
    }

    [dir=ltr] .md-sidebar--secondary:not([hidden])~.md-content>.md-content__inner,[dir=rtl] .md-sidebar--primary:not([hidden])~.md-content>.md-content__inner {
        margin-right: 1.5rem
    }

    [dir=rtl] .md-sidebar--secondary:not([hidden])~.md-content>.md-content__inner {
        margin-left: 1.5rem
    }
}

.md-content__inner:before {
    content: "";
    display: block;
    height: 0.5rem
}

.md-content__inner>:last-child {
    margin-bottom: 0
}

[dir=ltr] .md-content__button {
    float: right
}

[dir=rtl] .md-content__button {
    float: left
}

[dir=ltr] .md-content__button {
    margin-left: 0.5rem
}

[dir=rtl] .md-content__button {
    margin-right: 0.5rem
}

.md-content__button {
    margin: 0.5rem 0;
    padding: 0
}

@media print {
    .md-content__button {
        display: none
    }
}

.md-typeset .md-content__button {
    color: var(--md-default-fg-color--lighter)
}

.md-content__button svg {
    display: inline;
    vertical-align: top
}

[dir=rtl] .md-content__button svg {
    transform: scaleX(-1)
}

[dir=ltr] .md-dialog {
    right: 1rem
}

[dir=rtl] .md-dialog {
    left: 1rem
}

.md-dialog {
    background-color: var(--md-default-fg-color);
    border-radius: 0.125rem;
    bottom: 1rem;
    box-shadow: var(--md-shadow-z3);
    min-width: 13.875rem;
    opacity: 0;
    padding: 0.5rem 0.75rem;
    pointer-events: none;
    position: fixed;
    transform: translateY(100%);
    transition: transform 0ms .4s,opacity .4s;
    z-index: 4
}

@media print {
    .md-dialog {
        display: none
    }
}

.md-dialog--active {
    opacity: 1;
    pointer-events: auto;
    transform: translateY(0);
    transition: transform .4s cubic-bezier(.075,.85,.175,1),opacity .4s
}

.md-dialog__inner {
    color: var(--md-default-bg-color);
    font-size: 0.875rem
}

.md-feedback {
    margin: 2em 0 1em;
    text-align: center
}

.md-feedback fieldset {
    border: none;
    margin: 0;
    padding: 0
}

.md-feedback__title {
    font-weight: 700;
    margin: 1em auto
}

.md-feedback__inner {
    position: relative
}

.md-feedback__list {
    align-content: baseline;
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    position: relative
}

.md-feedback__list:hover .md-icon:not(:disabled) {
    color: var(--md-default-fg-color--lighter)
}

:disabled .md-feedback__list {
    min-height: 2.25rem
}

.md-feedback__icon {
    color: var(--md-default-fg-color--light);
    cursor: pointer;
    flex-shrink: 0;
    margin: 0 0.125rem;
    transition: color 125ms
}

.md-feedback__icon:not(:disabled).md-icon:hover {
    color: var(--md-accent-fg-color)
}

.md-feedback__icon:disabled {
    color: var(--md-default-fg-color--lightest);
    pointer-events: none
}

.md-feedback__note {
    opacity: 0;
    position: relative;
    transform: translateY(0.5rem);
    transition: transform .4s cubic-bezier(.1,.7,.1,1),opacity .15s
}

.md-feedback__note>* {
    margin: 0 auto;
    max-width: 20rem
}

:disabled .md-feedback__note {
    opacity: 1;
    transform: translateY(0)
}

.md-footer {
    background-color: var(--md-footer-bg-color);
    color: var(--md-footer-fg-color)
}

@media print {
    .md-footer {
        display: none
    }
}

.md-footer__inner {
    justify-content: space-between;
    overflow: auto;
    padding: 0.25rem
}

.md-footer__inner:not([hidden]) {
    display: flex
}

.md-footer__link {
    align-items: end;
    display: flex;
    flex-grow: 0.01;
    margin-bottom: 0.5rem;
    margin-top: 1.25rem;
    max-width: 100%;
    outline-color: var(--md-accent-fg-color);
    overflow: hidden;
    transition: opacity .25s
}

.md-footer__link:focus,.md-footer__link:hover {
    opacity: .7
}

[dir=rtl] .md-footer__link svg {
    transform: scaleX(-1)
}

@media screen and (max-width: 44.9375em) {
    .md-footer__link--prev {
        flex-shrink:0
    }

    .md-footer__link--prev .md-footer__title {
        display: none
    }
}

[dir=ltr] .md-footer__link--next {
    margin-left: auto
}

[dir=rtl] .md-footer__link--next {
    margin-right: auto
}

.md-footer__link--next {
    text-align: right
}

[dir=rtl] .md-footer__link--next {
    text-align: left
}

.md-footer__title {
    flex-grow: 1;
    font-size: 1.125rem;
    margin-bottom: 0.875rem;
    max-width: calc(100% - 3rem);
    padding: 0 1.25rem;
    white-space: nowrap
}

.md-footer__button {
    margin: 0.25rem;
    padding: 0.5rem
}

.md-footer__direction {
    font-size: 0.8rem;
    opacity: .7
}

.md-footer-meta {
    background-color: var(--md-footer-bg-color--dark)
}

.md-footer-meta__inner {
    display: flex;
    flex-wrap: wrap;
    justify-content: space-between;
    padding: 0.25rem
}

html .md-footer-meta.md-typeset a {
    color: var(--md-footer-fg-color--light)
}

html .md-footer-meta.md-typeset a:focus,html .md-footer-meta.md-typeset a:hover {
    color: var(--md-footer-fg-color)
}

.md-copyright {
    color: var(--md-footer-fg-color--lighter);
    font-size: 0.8rem;
    margin: auto 0.75rem;
    padding: 0.5rem 0;
    width: 100%
}

@media screen and (min-width: 45em) {
    .md-copyright {
        width:auto
    }
}

.md-copyright__highlight {
    color: var(--md-footer-fg-color--light)
}

.md-social {
    display: inline-flex;
    gap: 0.25rem;
    margin: 0 0.5rem;
    padding: 0.25rem 0 0.75rem
}

@media screen and (min-width: 45em) {
    .md-social {
        padding:0.75rem 0
    }
}

.md-social__link {
    display: inline-block;
    height: 2rem;
    text-align: center;
    width: 2rem
}

.md-social__link:before {
    line-height: 1.9
}

.md-social__link svg {
    fill: currentcolor;
    max-height: 1rem;
    vertical-align: -25%
}

.md-typeset .md-button {
    border: 0.125rem solid;
    border-radius: 0.125rem;
    color: var(--md-primary-fg-color);
    cursor: pointer;
    display: inline-block;
    font-weight: 700;
    padding: .625em 2em;
    transition: color 125ms,background-color 125ms,border-color 125ms
}

.md-typeset .md-button--primary {
    background-color: var(--md-primary-fg-color);
    border-color: var(--md-primary-fg-color);
    color: var(--md-primary-bg-color)
}

.md-typeset .md-button:focus,.md-typeset .md-button:hover {
    background-color: var(--md-accent-fg-color);
    border-color: var(--md-accent-fg-color);
    color: var(--md-accent-bg-color)
}

[dir=ltr] .md-typeset .md-input {
    border-top-left-radius: 0.125rem
}

[dir=ltr] .md-typeset .md-input,[dir=rtl] .md-typeset .md-input {
    border-top-right-radius: 0.125rem
}

[dir=rtl] .md-typeset .md-input {
    border-top-left-radius: 0.125rem
}

.md-typeset .md-input {
    border-bottom: 0.125rem solid var(--md-default-fg-color--lighter);
    box-shadow: var(--md-shadow-z1);
    font-size: 1rem;
    height: 2.25rem;
    padding: 0 0.75rem;
    transition: border .25s,box-shadow .25s
}

.md-typeset .md-input:focus,.md-typeset .md-input:hover {
    border-bottom-color: var(--md-accent-fg-color);
    box-shadow: var(--md-shadow-z2)
}

.md-typeset .md-input--stretch {
    width: 100%
}

.md-header {
    background-color: var(--md-primary-fg-color);
    box-shadow: 0 0 0.25rem #0000,0 0.25rem 0.5rem #0000;
    color: var(--md-primary-bg-color);
    display: block;
    left: 0;
    position: sticky;
    right: 0;
    top: 0;
    z-index: 4
}

@media print {
    .md-header {
        display: none
    }
}

.md-header[hidden] {
    transform: translateY(-100%);
    transition: transform .25s cubic-bezier(.8,0,.6,1),box-shadow .25s
}

.md-header--shadow {
    box-shadow: 0 0 0.25rem #0000001a,0 0.25rem 0.5rem #0003;
    transition: transform .25s cubic-bezier(.1,.7,.1,1),box-shadow .25s
}

.md-header__inner {
    align-items: center;
    display: flex;
    padding: 0 0.25rem
}

.md-header__button {
    color: currentcolor;
    cursor: pointer;
    margin: 0.25rem;
    outline-color: var(--md-accent-fg-color);
    padding: 0.5rem;
    position: relative;
    transition: opacity .25s;
    vertical-align: middle;
    z-index: 1
}

.md-header__button:hover {
    opacity: .7
}

.md-header__button:not([hidden]) {
    display: inline-block
}

.md-header__button:not(.focus-visible) {
    -webkit-tap-highlight-color: transparent;
    outline: none
}

.md-header__button.md-logo {
    margin: 0.25rem;
    padding: 0.5rem
}

@media screen and (max-width: 76.1875em) {
    .md-header__button.md-logo {
        display:none
    }
}

.md-header__button.md-logo img,.md-header__button.md-logo svg {
    fill: currentcolor;
    display: block;
    height: 1.5rem;
    width: auto
}

@media screen and (min-width: 60em) {
    .md-header__button[for=__search] {
        display:none
    }
}

.no-js .md-header__button[for=__search] {
    display: none
}

[dir=rtl] .md-header__button[for=__search] svg {
    transform: scaleX(-1)
}

@media screen and (min-width: 76.25em) {
    .md-header__button[for=__drawer] {
        display:none
    }
}

.md-header__topic {
    display: flex;
    max-width: 100%;
    position: absolute;
    transition: transform .4s cubic-bezier(.1,.7,.1,1),opacity .15s;
    white-space: nowrap
}

.md-header__topic+.md-header__topic {
    opacity: 0;
    pointer-events: none;
    transform: translateX(1.5625rem);
    transition: transform .4s cubic-bezier(1,.7,.1,.1),opacity .15s;
    z-index: -1
}

[dir=rtl] .md-header__topic+.md-header__topic {
    transform: translateX(-1.5625rem)
}

.md-header__topic:first-child {
    font-weight: 700
}

[dir=ltr] .md-header__title {
    margin-left: 1.25rem
}

[dir=rtl] .md-header__title {
    margin-right: 1.25rem
}

[dir=ltr] .md-header__title {
    margin-right: 0.5rem
}

[dir=rtl] .md-header__title {
    margin-left: 0.5rem
}

.md-header__title {
    flex-grow: 1;
    font-size: 1.125rem;
    height: 3rem;
    line-height: 3rem
}

.md-header__title--active .md-header__topic {
    opacity: 0;
    pointer-events: none;
    transform: translateX(-1.5625rem);
    transition: transform .4s cubic-bezier(1,.7,.1,.1),opacity .15s;
    z-index: -1
}

[dir=rtl] .md-header__title--active .md-header__topic {
    transform: translateX(1.5625rem)
}

.md-header__title--active .md-header__topic+.md-header__topic {
    opacity: 1;
    pointer-events: auto;
    transform: translateX(0);
    transition: transform .4s cubic-bezier(.1,.7,.1,1),opacity .15s;
    z-index: 0
}

.md-header__title>.md-header__ellipsis {
    height: 100%;
    position: relative;
    width: 100%
}

.md-header__option {
    display: flex;
    flex-shrink: 0;
    max-width: 100%;
    transition: max-width 0ms .25s,opacity .25s .25s;
    white-space: nowrap
}

[data-md-toggle=search]:checked~.md-header .md-header__option {
    max-width: 0;
    opacity: 0;
    transition: max-width 0ms,opacity 0ms
}

.md-header__option>input {
    bottom: 0
}

.md-header__source {
    display: none
}

@media screen and (min-width: 60em) {
    [dir=ltr] .md-header__source {
        margin-left:1.25rem
    }

    [dir=rtl] .md-header__source {
        margin-right: 1.25rem
    }

    .md-header__source {
        display: block;
        max-width: 14.625rem;
        width: 14.625rem
    }
}

@media screen and (min-width: 76.25em) {
    [dir=ltr] .md-header__source {
        margin-left:1.75rem
    }

    [dir=rtl] .md-header__source {
        margin-right: 1.75rem
    }
}

.md-meta {
    color: var(--md-default-fg-color--light);
    font-size: 0.875rem;
    line-height: 1.3
}

.md-meta__list {
    display: inline-flex;
    flex-wrap: wrap;
    list-style: none;
    margin: 0;
    padding: 0
}

.md-meta__item:not(:last-child):after {
    content: "·";
    margin-left: 0.25rem;
    margin-right: 0.25rem
}

.md-meta__link {
    color: var(--md-typeset-a-color)
}

.md-meta__link:focus,.md-meta__link:hover {
    color: var(--md-accent-fg-color)
}

.md-draft {
    background-color: #ff1744;
    border-radius: .125em;
    color: #fff;
    display: inline-block;
    font-weight: 700;
    padding-left: .5714285714em;
    padding-right: .5714285714em
}

:root {
    --md-nav-icon--prev: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M20 11v2H8l5.5 5.5-1.42 1.42L4.16 12l7.92-7.92L13.5 5.5 8 11h12Z"/></svg>');
    --md-nav-icon--next: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M8.59 16.58 13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.42Z"/></svg>');
    --md-toc-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M3 9h14V7H3v2m0 4h14v-2H3v2m0 4h14v-2H3v2m16 0h2v-2h-2v2m0-10v2h2V7h-2m0 6h2v-2h-2v2Z"/></svg>')
}

.md-nav {
    font-size: 0.875rem;
    line-height: 1.3
}

.md-nav__title {
    color: var(--md-default-fg-color--light);
    display: block;
    font-weight: 700;
    overflow: hidden;
    padding: 0 0.75rem;
    text-overflow: ellipsis
}

.md-nav__title .md-nav__button {
    display: none
}

.md-nav__title .md-nav__button img {
    height: 100%;
    width: auto
}

.md-nav__title .md-nav__button.md-logo img,.md-nav__title .md-nav__button.md-logo svg {
    fill: currentcolor;
    display: block;
    height: 3rem;
    max-width: 100%;
    object-fit: contain;
    width: auto
}

.md-nav__list {
    list-style: none;
    margin: 0;
    padding: 0
}

.md-nav__item {
    padding: 0 0.75rem
}

[dir=ltr] .md-nav__item .md-nav__item {
    padding-right: 0
}

[dir=rtl] .md-nav__item .md-nav__item {
    padding-left: 0
}

.md-nav__link {
    align-items: flex-start;
    display: flex;
    margin-top: .625em;
    scroll-snap-align: start;
    transition: color 125ms
}

.md-nav__link--passed {
    color: var(--md-default-fg-color--light)
}

.md-nav__item .md-nav__link--active,.md-nav__item .md-nav__link--active code {
    color: var(--md-typeset-a-color)
}

.md-nav__link .md-ellipsis {
    position: relative
}

.md-nav__link .md-icon:last-child {
    margin-left: auto
}

.md-nav__link svg {
    fill: currentcolor;
    flex-shrink: 0;
    height: 1.3em
}

[dir=ltr] .md-nav__link svg+* {
    margin-left: 0.5rem
}

[dir=rtl] .md-nav__link svg+* {
    margin-right: 0.5rem
}

.md-nav__link:not(.md-nav__container):focus,.md-nav__link:not(.md-nav__container):hover {
    color: var(--md-accent-fg-color);
    cursor: pointer
}

.md-nav__link.focus-visible {
    outline-color: var(--md-accent-fg-color);
    outline-offset: 0.25rem
}

.md-nav--primary .md-nav__link[for=__toc] {
    display: none
}

.md-nav--primary .md-nav__link[for=__toc] .md-icon:after {
    background-color: currentcolor;
    display: block;
    height: 100%;
    -webkit-mask-image: var(--md-toc-icon);
    mask-image: var(--md-toc-icon);
    width: 100%
}

.md-nav--primary .md-nav__link[for=__toc]~.md-nav {
    display: none
}

.md-nav__container>.md-nav__link {
    margin-top: 0
}

.md-nav__container>.md-nav__link:first-child {
    flex-grow: 1
}

.md-nav__icon {
    flex-shrink: 0
}

.md-nav__source {
    display: none
}

@media screen and (max-width: 76.1875em) {
    .md-nav--primary,.md-nav--primary .md-nav {
        background-color:var(--md-default-bg-color);
        display: flex;
        flex-direction: column;
        height: 100%;
        left: 0;
        position: absolute;
        right: 0;
        top: 0;
        z-index: 1
    }

    .md-nav--primary .md-nav__item,.md-nav--primary .md-nav__title {
        font-size: 1rem;
        line-height: 1.5
    }

    .md-nav--primary .md-nav__title {
        background-color: var(--md-default-fg-color--lightest);
        color: var(--md-default-fg-color--light);
        cursor: pointer;
        height: 7rem;
        line-height: 3rem;
        padding: 3.75rem 1rem 0.25rem;
        position: relative;
        white-space: nowrap
    }

    [dir=ltr] .md-nav--primary .md-nav__title .md-nav__icon {
        left: 0.5rem
    }

    [dir=rtl] .md-nav--primary .md-nav__title .md-nav__icon {
        right: 0.5rem
    }

    .md-nav--primary .md-nav__title .md-nav__icon {
        display: block;
        height: 1.5rem;
        margin: 0.25rem;
        position: absolute;
        top: 0.5rem;
        width: 1.5rem
    }

    .md-nav--primary .md-nav__title .md-nav__icon:after {
        background-color: currentcolor;
        content: "";
        display: block;
        height: 100%;
        -webkit-mask-image: var(--md-nav-icon--prev);
        mask-image: var(--md-nav-icon--prev);
        -webkit-mask-position: center;
        mask-position: center;
        -webkit-mask-repeat: no-repeat;
        mask-repeat: no-repeat;
        -webkit-mask-size: contain;
        mask-size: contain;
        width: 100%
    }

    .md-nav--primary .md-nav__title~.md-nav__list {
        background-color: var(--md-default-bg-color);
        box-shadow: 0 0.0625rem 0 var(--md-default-fg-color--lightest) inset;
        overflow-y: auto;
        scroll-snap-type: y mandatory;
        touch-action: pan-y
    }

    .md-nav--primary .md-nav__title~.md-nav__list>:first-child {
        border-top: 0
    }

    .md-nav--primary .md-nav__title[for=__drawer] {
        background-color: var(--md-primary-fg-color);
        color: var(--md-primary-bg-color);
        font-weight: 700
    }

    .md-nav--primary .md-nav__title .md-logo {
        display: block;
        left: 0.25rem;
        margin: 0.25rem;
        padding: 0.5rem;
        position: absolute;
        right: 0.25rem;
        top: 0.25rem
    }

    .md-nav--primary .md-nav__list {
        flex: 1
    }

    .md-nav--primary .md-nav__item {
        border-top: 0.0625rem solid var(--md-default-fg-color--lightest);
        padding: 0
    }

    .md-nav--primary .md-nav__item--active>.md-nav__link {
        color: var(--md-typeset-a-color)
    }

    .md-nav--primary .md-nav__item--active>.md-nav__link:focus,.md-nav--primary .md-nav__item--active>.md-nav__link:hover {
        color: var(--md-accent-fg-color)
    }

    .md-nav--primary .md-nav__link {
        margin-top: 0;
        padding: 0.75rem 1rem
    }

    .md-nav--primary .md-nav__link svg {
        margin-top: .1em
    }

    .md-nav--primary .md-nav__link>.md-nav__link {
        padding: 0
    }

    [dir=ltr] .md-nav--primary .md-nav__link .md-nav__icon {
        margin-right: -0.25rem
    }

    [dir=rtl] .md-nav--primary .md-nav__link .md-nav__icon {
        margin-left: -0.25rem
    }

    .md-nav--primary .md-nav__link .md-nav__icon {
        font-size: 1.5rem;
        height: 1.5rem;
        width: 1.5rem
    }

    .md-nav--primary .md-nav__link .md-nav__icon:after {
        background-color: currentcolor;
        content: "";
        display: block;
        height: 100%;
        -webkit-mask-image: var(--md-nav-icon--next);
        mask-image: var(--md-nav-icon--next);
        -webkit-mask-position: center;
        mask-position: center;
        -webkit-mask-repeat: no-repeat;
        mask-repeat: no-repeat;
        -webkit-mask-size: contain;
        mask-size: contain;
        width: 100%
    }

    [dir=rtl] .md-nav--primary .md-nav__icon:after {
        transform: scale(-1)
    }

    .md-nav--primary .md-nav--secondary .md-nav {
        background-color: initial;
        position: static
    }

    [dir=ltr] .md-nav--primary .md-nav--secondary .md-nav .md-nav__link {
        padding-left: 1.75rem
    }

    [dir=rtl] .md-nav--primary .md-nav--secondary .md-nav .md-nav__link {
        padding-right: 1.75rem
    }

    [dir=ltr] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav__link {
        padding-left: 2.5rem
    }

    [dir=rtl] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav__link {
        padding-right: 2.5rem
    }

    [dir=ltr] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav .md-nav__link {
        padding-left: 3.25rem
    }

    [dir=rtl] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav .md-nav__link {
        padding-right: 3.25rem
    }

    [dir=ltr] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav .md-nav .md-nav__link {
        padding-left: 4rem
    }

    [dir=rtl] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav .md-nav .md-nav__link {
        padding-right: 4rem
    }

    .md-nav--secondary {
        background-color: initial
    }

    .md-nav__toggle~.md-nav {
        display: flex;
        opacity: 0;
        transform: translateX(100%);
        transition: transform .25s cubic-bezier(.8,0,.6,1),opacity 125ms 50ms
    }

    [dir=rtl] .md-nav__toggle~.md-nav {
        transform: translateX(-100%)
    }

    .md-nav__toggle:checked~.md-nav {
        opacity: 1;
        transform: translateX(0);
        transition: transform .25s cubic-bezier(.4,0,.2,1),opacity 125ms 125ms
    }

    .md-nav__toggle:checked~.md-nav>.md-nav__list {
        -webkit-backface-visibility: hidden;
        backface-visibility: hidden
    }
}

@media screen and (max-width: 59.9375em) {
    .md-nav--primary .md-nav__link[for=__toc] {
        display:flex
    }

    .md-nav--primary .md-nav__link[for=__toc] .md-icon:after {
        content: ""
    }

    .md-nav--primary .md-nav__link[for=__toc]+.md-nav__link {
        display: none
    }

    .md-nav--primary .md-nav__link[for=__toc]~.md-nav {
        display: flex
    }

    .md-nav__source {
        background-color: var(--md-primary-fg-color--dark);
        color: var(--md-primary-bg-color);
        display: block;
        padding: 0 0.25rem
    }
}

@media screen and (min-width: 60em) and (max-width:76.1875em) {
    .md-nav--integrated .md-nav__link[for=__toc] {
        display:flex
    }

    .md-nav--integrated .md-nav__link[for=__toc] .md-icon:after {
        content: ""
    }

    .md-nav--integrated .md-nav__link[for=__toc]+.md-nav__link {
        display: none
    }

    .md-nav--integrated .md-nav__link[for=__toc]~.md-nav {
        display: flex
    }
}

@media screen and (min-width: 60em) {
    .md-nav--secondary .md-nav__title {
        background:var(--md-default-bg-color);
        box-shadow: 0 0 0.5rem 0.5rem var(--md-default-bg-color);
        position: sticky;
        top: 0;
        z-index: 1
    }

    .md-nav--secondary .md-nav__title[for=__toc] {
        scroll-snap-align: start
    }

    .md-nav--secondary .md-nav__title .md-nav__icon {
        display: none
    }
}

@media screen and (min-width: 76.25em) {
    .md-nav {
        transition:max-height .25s cubic-bezier(.86,0,.07,1)
    }

    .md-nav--primary .md-nav__title {
        background: var(--md-default-bg-color);
        box-shadow: 0 0 0.5rem 0.5rem var(--md-default-bg-color);
        position: sticky;
        top: 0;
        z-index: 1
    }

    .md-nav--primary .md-nav__title[for=__drawer] {
        scroll-snap-align: start
    }

    .md-nav--primary .md-nav__title .md-nav__icon,.md-nav__toggle~.md-nav {
        display: none
    }

    .md-nav__toggle:checked~.md-nav,.md-nav__toggle:indeterminate~.md-nav {
        display: block
    }

    .md-nav__item--nested>.md-nav>.md-nav__title {
        display: none
    }

    .md-nav__item--section {
        display: block;
        margin: 1.25em 0
    }

    .md-nav__item--section:last-child {
        margin-bottom: 0
    }

    .md-nav__item--section>.md-nav__link {
        font-weight: 700
    }

    .md-nav__item--section>.md-nav__link[for] {
        color: var(--md-default-fg-color--light)
    }

    .md-nav__item--section>.md-nav__link:not(.md-nav__container) {
        pointer-events: none
    }

    .md-nav__item--section>.md-nav__link .md-nav__icon {
        display: none
    }

    .md-nav__item--section>.md-nav {
        display: block
    }

    .md-nav__item--section>.md-nav>.md-nav__list>.md-nav__item {
        padding: 0
    }

    .md-nav__icon {
        border-radius: 100%;
        height: 1.125rem;
        transition: background-color .25s;
        width: 1.125rem
    }

    .md-nav__icon:hover {
        background-color: var(--md-accent-fg-color--transparent)
    }

    .md-nav__icon:after {
        background-color: currentcolor;
        border-radius: 100%;
        content: "";
        display: inline-block;
        height: 100%;
        -webkit-mask-image: var(--md-nav-icon--next);
        mask-image: var(--md-nav-icon--next);
        -webkit-mask-position: center;
        mask-position: center;
        -webkit-mask-repeat: no-repeat;
        mask-repeat: no-repeat;
        -webkit-mask-size: contain;
        mask-size: contain;
        transition: transform .25s;
        vertical-align: -0.125rem;
        width: 100%
    }

    [dir=rtl] .md-nav__icon:after {
        transform: rotate(180deg)
    }

    .md-nav__item--nested .md-nav__toggle:checked~.md-nav__link .md-nav__icon:after,.md-nav__item--nested .md-nav__toggle:indeterminate~.md-nav__link .md-nav__icon:after {
        transform: rotate(90deg)
    }

    .md-nav--lifted>.md-nav__list>.md-nav__item,.md-nav--lifted>.md-nav__list>.md-nav__item--nested,.md-nav--lifted>.md-nav__title {
        display: none
    }

    .md-nav--lifted>.md-nav__list>.md-nav__item--active {
        display: block;
        padding: 0
    }

    .md-nav--lifted>.md-nav__list>.md-nav__item--active>.md-nav__link {
        background: var(--md-default-bg-color);
        box-shadow: 0 0 0.5rem 0.5rem var(--md-default-bg-color);
        font-weight: 700;
        margin-top: 0;
        padding: 0 0.75rem;
        position: sticky;
        top: 0;
        z-index: 1
    }

    .md-nav--lifted>.md-nav__list>.md-nav__item--active>.md-nav__link:not(.md-nav__container) {
        pointer-events: none
    }

    .md-nav--lifted>.md-nav__list>.md-nav__item--active>.md-nav__link .md-nav__icon {
        display: none
    }

    .md-nav--lifted>.md-nav__list>.md-nav__item>[for] {
        color: var(--md-default-fg-color--light)
    }

    .md-nav--lifted .md-nav[data-md-level="1"] {
        display: block
    }

    [dir=ltr] .md-nav--lifted .md-nav[data-md-level="1"]>.md-nav__list>.md-nav__item {
        padding-right: 0.75rem
    }

    [dir=rtl] .md-nav--lifted .md-nav[data-md-level="1"]>.md-nav__list>.md-nav__item {
        padding-left: 0.75rem
    }

    .md-nav--integrated>.md-nav__list>.md-nav__item--active:not(.md-nav__item--nested) {
        padding: 0 0.75rem
    }

    .md-nav--integrated>.md-nav__list>.md-nav__item--active:not(.md-nav__item--nested)>.md-nav__link {
        padding: 0
    }

    [dir=ltr] .md-nav--integrated>.md-nav__list>.md-nav__item--active .md-nav--secondary {
        border-left: 0.0625rem solid var(--md-primary-fg-color)
    }

    [dir=rtl] .md-nav--integrated>.md-nav__list>.md-nav__item--active .md-nav--secondary {
        border-right: 0.0625rem solid var(--md-primary-fg-color)
    }

    .md-nav--integrated>.md-nav__list>.md-nav__item--active .md-nav--secondary {
        display: block;
        margin-bottom: 1.25em
    }

    .md-nav--integrated>.md-nav__list>.md-nav__item--active .md-nav--secondary>.md-nav__title {
        display: none
    }
}

.md-pagination {
    font-size: 1rem;
    font-weight: 700;
    gap: 0.5rem
}

.md-pagination,.md-pagination>* {
    align-items: center;
    display: flex;
    justify-content: center
}

.md-pagination>* {
    border-radius: 0.25rem;
    height: 2.25rem;
    min-width: 2.25rem;
    text-align: center
}

.md-pagination__current {
    background-color: var(--md-default-fg-color--lightest);
    color: var(--md-default-fg-color--light)
}

.md-pagination__link {
    transition: color 125ms,background-color 125ms
}

.md-pagination__link:focus,.md-pagination__link:hover {
    background-color: var(--md-accent-fg-color--transparent);
    color: var(--md-accent-fg-color)
}

.md-pagination__link:focus svg,.md-pagination__link:hover svg {
    color: var(--md-accent-fg-color)
}

.md-pagination__link.focus-visible {
    outline-color: var(--md-accent-fg-color);
    outline-offset: 0.25rem
}

.md-pagination__link svg {
    fill: currentcolor;
    color: var(--md-default-fg-color--lighter);
    display: block;
    max-height: 100%;
    width: 1.5rem
}

.md-post__back {
    border-bottom: 0.0625rem solid var(--md-default-fg-color--lightest);
    margin-bottom: 1.5rem;
    padding-bottom: 1.5rem
}

@media screen and (max-width: 76.1875em) {
    .md-post__back {
        display:none
    }
}

[dir=rtl] .md-post__back svg {
    transform: scaleX(-1)
}

.md-post__authors {
    display: flex;
    flex-direction: column;
    gap: 0.75rem;
    margin: 0 0.75rem
}

.md-post .md-post__meta a {
    transition: color 125ms
}

.md-post .md-post__meta a:focus,.md-post .md-post__meta a:hover {
    color: var(--md-accent-fg-color)
}

.md-post--excerpt {
    margin-bottom: 4rem
}

.md-post--excerpt .md-post__header {
    align-items: center;
    display: flex;
    gap: 0.75rem;
    min-height: 2rem
}

.md-post--excerpt .md-post__authors {
    align-items: center;
    display: inline-flex;
    flex-direction: row;
    gap: 0.25rem;
    margin: 0;
    min-height: 3rem
}

[dir=ltr] .md-post--excerpt .md-post__meta .md-meta__list {
    margin-right: 0.5rem
}

[dir=rtl] .md-post--excerpt .md-post__meta .md-meta__list {
    margin-left: 0.5rem
}

.md-post--excerpt .md-post__content>:first-child {
    --md-scroll-margin: 7.5rem;
    margin-top: 0
}

.md-post>.md-nav--secondary,.md-post>.md-nav:first-child>.md-nav__list {
    margin: 1em 0
}

.md-profile {
    align-items: center;
    display: flex;
    font-size: 0.875rem;
    gap: 0.75rem;
    line-height: 1.4;
    width: 100%
}

.md-profile__description {
    flex-grow: 1
}

.md-content--post {
    display: flex
}

@media screen and (max-width: 76.1875em) {
    .md-content--post {
        flex-flow:column-reverse
    }
}

.md-content--post>.md-content__inner {
    min-width: 0
}

@media screen and (min-width: 76.25em) {
    [dir=ltr] .md-content--post>.md-content__inner {
        margin-left:1.5rem
    }

    [dir=rtl] .md-content--post>.md-content__inner {
        margin-right: 1.5rem
    }
}

@media screen and (max-width: 76.1875em) {
    .md-sidebar.md-sidebar--post {
        padding:0
    }
}

:root {
    --md-search-result-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h7c-.41-.25-.8-.56-1.14-.9-.33-.33-.61-.7-.86-1.1H6V4h7v5h5v1.18c.71.16 1.39.43 2 .82V8l-6-6m6.31 16.9c1.33-2.11.69-4.9-1.4-6.22-2.11-1.33-4.91-.68-6.22 1.4-1.34 2.11-.69 4.89 1.4 6.22 1.46.93 3.32.93 4.79.02L22 23.39 23.39 22l-3.08-3.1m-3.81.1a2.5 2.5 0 0 1-2.5-2.5 2.5 2.5 0 0 1 2.5-2.5 2.5 2.5 0 0 1 2.5 2.5 2.5 2.5 0 0 1-2.5 2.5Z"/></svg>')
}

.md-search {
    position: relative
}

@media screen and (min-width: 60em) {
    .md-search {
        padding:0.25rem 0
    }
}

.no-js .md-search {
    display: none
}

.md-search__overlay {
    opacity: 0;
    z-index: 1
}

@media screen and (max-width: 59.9375em) {
    [dir=ltr] .md-search__overlay {
        left:-2.75rem
    }

    [dir=rtl] .md-search__overlay {
        right: -2.75rem
    }

    .md-search__overlay {
        background-color: var(--md-default-bg-color);
        border-radius: 1.25rem;
        height: 2.5rem;
        overflow: hidden;
        pointer-events: none;
        position: absolute;
        top: -1.25rem;
        transform-origin: center;
        transition: transform .3s .1s,opacity .2s .2s;
        width: 2.5rem
    }

    [data-md-toggle=search]:checked~.md-header .md-search__overlay {
        opacity: 1;
        transition: transform .4s,opacity .1s
    }
}

@media screen and (min-width: 60em) {
    [dir=ltr] .md-search__overlay {
        left:0
    }

    [dir=rtl] .md-search__overlay {
        right: 0
    }

    .md-search__overlay {
        background-color: #0000008a;
        cursor: pointer;
        height: 0;
        position: fixed;
        top: 0;
        transition: width 0ms .25s,height 0ms .25s,opacity .25s;
        width: 0
    }

    [data-md-toggle=search]:checked~.md-header .md-search__overlay {
        height: 200vh;
        opacity: 1;
        transition: width 0ms,height 0ms,opacity .25s;
        width: 100%
    }
}

@media screen and (max-width: 29.9375em) {
    [data-md-toggle=search]:checked~.md-header .md-search__overlay {
        transform:scale(45)
    }
}

@media screen and (min-width: 30em) and (max-width:44.9375em) {
    [data-md-toggle=search]:checked~.md-header .md-search__overlay {
        transform:scale(60)
    }
}

@media screen and (min-width: 45em) and (max-width:59.9375em) {
    [data-md-toggle=search]:checked~.md-header .md-search__overlay {
        transform:scale(75)
    }
}

.md-search__inner {
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden
}

@media screen and (max-width: 59.9375em) {
    [dir=ltr] .md-search__inner {
        left:0
    }

    [dir=rtl] .md-search__inner {
        right: 0
    }

    .md-search__inner {
        height: 0;
        opacity: 0;
        overflow: hidden;
        position: fixed;
        top: 0;
        transform: translateX(5%);
        transition: width 0ms .3s,height 0ms .3s,transform .15s cubic-bezier(.4,0,.2,1) .15s,opacity .15s .15s;
        width: 0;
        z-index: 2
    }

    [dir=rtl] .md-search__inner {
        transform: translateX(-5%)
    }

    [data-md-toggle=search]:checked~.md-header .md-search__inner {
        height: 100%;
        opacity: 1;
        transform: translateX(0);
        transition: width 0ms 0ms,height 0ms 0ms,transform .15s cubic-bezier(.1,.7,.1,1) .15s,opacity .15s .15s;
        width: 100%
    }
}

@media screen and (min-width: 60em) {
    [dir=ltr] .md-search__inner {
        float:right
    }

    [dir=rtl] .md-search__inner {
        float: left
    }

    .md-search__inner {
        padding: 0.125rem 0;
        position: relative;
        transition: width .25s cubic-bezier(.1,.7,.1,1);
        width: 14.625rem
    }
}

@media screen and (min-width: 60em) and (max-width:76.1875em) {
    [data-md-toggle=search]:checked~.md-header .md-search__inner {
        width:29.25rem
    }
}

@media screen and (min-width: 76.25em) {
    [data-md-toggle=search]:checked~.md-header .md-search__inner {
        width:43rem
    }
}

.md-search__form {
    background-color: var(--md-default-bg-color);
    box-shadow: 0 0 0.75rem #0000;
    height: 3rem;
    position: relative;
    transition: color .25s,background-color .25s;
    z-index: 2
}

@media screen and (min-width: 60em) {
    .md-search__form {
        background-color:#00000042;
        border-radius: 0.125rem;
        height: 2.25rem
    }

    .md-search__form:hover {
        background-color: #ffffff1f
    }
}

[data-md-toggle=search]:checked~.md-header .md-search__form {
    background-color: var(--md-default-bg-color);
    border-radius: 0.125rem 0.125rem 0 0;
    box-shadow: 0 0 0.75rem #00000012;
    color: var(--md-default-fg-color)
}

[dir=ltr] .md-search__input {
    padding-left: 4.5rem;
    padding-right: 2.75rem
}

[dir=rtl] .md-search__input {
    padding-left: 2.75rem;
    padding-right: 4.5rem
}

.md-search__input {
    background: #0000;
    font-size: 1.125rem;
    height: 100%;
    position: relative;
    text-overflow: ellipsis;
    width: 100%;
    z-index: 2
}

.md-search__input::placeholder {
    transition: color .25s
}

.md-search__input::placeholder,.md-search__input~.md-search__icon {
    color: var(--md-default-fg-color--light)
}

.md-search__input::-ms-clear {
    display: none
}

@media screen and (max-width: 59.9375em) {
    .md-search__input {
        font-size:1.125rem;
        height: 3rem;
        width: 100%
    }
}

@media screen and (min-width: 60em) {
    [dir=ltr] .md-search__input {
        padding-left:2.75rem
    }

    [dir=rtl] .md-search__input {
        padding-right: 2.75rem
    }

    .md-search__input {
        color: inherit;
        font-size: 1rem
    }

    .md-search__input::placeholder {
        color: var(--md-primary-bg-color--light)
    }

    .md-search__input+.md-search__icon {
        color: var(--md-primary-bg-color)
    }

    [data-md-toggle=search]:checked~.md-header .md-search__input {
        text-overflow: clip
    }

    [data-md-toggle=search]:checked~.md-header .md-search__input+.md-search__icon {
        color: var(--md-default-fg-color--light)
    }

    [data-md-toggle=search]:checked~.md-header .md-search__input::placeholder {
        color: #0000
    }
}

.md-search__icon {
    cursor: pointer;
    display: inline-block;
    height: 1.5rem;
    transition: color .25s,opacity .25s;
    width: 1.5rem
}

.md-search__icon:hover {
    opacity: .7
}

[dir=ltr] .md-search__icon[for=__search] {
    left: 0.625rem
}

[dir=rtl] .md-search__icon[for=__search] {
    right: 0.625rem
}

.md-search__icon[for=__search] {
    position: absolute;
    top: 0.375rem;
    z-index: 2
}

[dir=rtl] .md-search__icon[for=__search] svg {
    transform: scaleX(-1)
}

@media screen and (max-width: 59.9375em) {
    [dir=ltr] .md-search__icon[for=__search] {
        left:1rem
    }

    [dir=rtl] .md-search__icon[for=__search] {
        right: 1rem
    }

    .md-search__icon[for=__search] {
        top: 0.75rem
    }

    .md-search__icon[for=__search] svg:first-child {
        display: none
    }
}

@media screen and (min-width: 60em) {
    .md-search__icon[for=__search] {
        pointer-events:none
    }

    .md-search__icon[for=__search] svg:last-child {
        display: none
    }
}

[dir=ltr] .md-search__options {
    right: 0.625rem
}

[dir=rtl] .md-search__options {
    left: 0.625rem
}

.md-search__options {
    pointer-events: none;
    position: absolute;
    top: 0.375rem;
    z-index: 2
}

@media screen and (max-width: 59.9375em) {
    [dir=ltr] .md-search__options {
        right:1rem
    }

    [dir=rtl] .md-search__options {
        left: 1rem
    }

    .md-search__options {
        top: 0.75rem
    }
}

[dir=ltr] .md-search__options>.md-icon {
    margin-left: 0.25rem
}

[dir=rtl] .md-search__options>.md-icon {
    margin-right: 0.25rem
}

.md-search__options>.md-icon {
    color: var(--md-default-fg-color--light);
    opacity: 0;
    transform: scale(.75);
    transition: transform .15s cubic-bezier(.1,.7,.1,1),opacity .15s
}

.md-search__options>.md-icon:not(.focus-visible) {
    -webkit-tap-highlight-color: transparent;
    outline: none
}

[data-md-toggle=search]:checked~.md-header .md-search__input:valid~.md-search__options>.md-icon {
    opacity: 1;
    pointer-events: auto;
    transform: scale(1)
}

[data-md-toggle=search]:checked~.md-header .md-search__input:valid~.md-search__options>.md-icon:hover {
    opacity: .7
}

[dir=ltr] .md-search__suggest {
    padding-left: 4.5rem;
    padding-right: 2.75rem
}

[dir=rtl] .md-search__suggest {
    padding-left: 2.75rem;
    padding-right: 4.5rem
}

.md-search__suggest {
    align-items: center;
    color: var(--md-default-fg-color--lighter);
    display: flex;
    font-size: 1.125rem;
    height: 100%;
    opacity: 0;
    position: absolute;
    top: 0;
    transition: opacity 50ms;
    white-space: nowrap;
    width: 100%
}

@media screen and (min-width: 60em) {
    [dir=ltr] .md-search__suggest {
        padding-left:2.75rem
    }

    [dir=rtl] .md-search__suggest {
        padding-right: 2.75rem
    }

    .md-search__suggest {
        font-size: 1rem
    }
}

[data-md-toggle=search]:checked~.md-header .md-search__suggest {
    opacity: 1;
    transition: opacity .3s .1s
}

[dir=ltr] .md-search__output {
    border-bottom-left-radius: 0.125rem
}

[dir=ltr] .md-search__output,[dir=rtl] .md-search__output {
    border-bottom-right-radius: 0.125rem
}

[dir=rtl] .md-search__output {
    border-bottom-left-radius: 0.125rem
}

.md-search__output {
    overflow: hidden;
    position: absolute;
    width: 100%;
    z-index: 1
}

@media screen and (max-width: 59.9375em) {
    .md-search__output {
        bottom:0;
        top: 3rem
    }
}

@media screen and (min-width: 60em) {
    .md-search__output {
        opacity:0;
        top: 2.375rem;
        transition: opacity .4s
    }

    [data-md-toggle=search]:checked~.md-header .md-search__output {
        box-shadow: var(--md-shadow-z3);
        opacity: 1
    }
}

.md-search__scrollwrap {
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden;
    background-color: var(--md-default-bg-color);
    height: 100%;
    overflow-y: auto;
    touch-action: pan-y
}

@media (-webkit-max-device-pixel-ratio: 1),(max-resolution:1dppx) {
    .md-search__scrollwrap {
        transform:translateZ(0)
    }
}

@media screen and (min-width: 60em) and (max-width:76.1875em) {
    .md-search__scrollwrap {
        width:29.25rem
    }
}

@media screen and (min-width: 76.25em) {
    .md-search__scrollwrap {
        width:43rem
    }
}

@media screen and (min-width: 60em) {
    .md-search__scrollwrap {
        max-height:0;
        scrollbar-color: var(--md-default-fg-color--lighter) #0000;
        scrollbar-width: thin
    }

    [data-md-toggle=search]:checked~.md-header .md-search__scrollwrap {
        max-height: 75vh
    }

    .md-search__scrollwrap:hover {
        scrollbar-color: var(--md-accent-fg-color) #0000
    }

    .md-search__scrollwrap::-webkit-scrollbar {
        height: 0.25rem;
        width: 0.25rem
    }

    .md-search__scrollwrap::-webkit-scrollbar-thumb {
        background-color: var(--md-default-fg-color--lighter)
    }

    .md-search__scrollwrap::-webkit-scrollbar-thumb:hover {
        background-color: var(--md-accent-fg-color)
    }
}

.md-search-result {
    color: var(--md-default-fg-color);
    word-break: break-word
}

.md-search-result__meta {
    background-color: var(--md-default-fg-color--lightest);
    color: var(--md-default-fg-color--light);
    font-size: 0.8rem;
    line-height: 2.25rem;
    padding: 0 1rem;
    scroll-snap-align: start
}

@media screen and (min-width: 60em) {
    [dir=ltr] .md-search-result__meta {
        padding-left:2.75rem
    }

    [dir=rtl] .md-search-result__meta {
        padding-right: 2.75rem
    }
}

.md-search-result__list {
    list-style: none;
    margin: 0;
    padding: 0;
    -webkit-user-select: none;
    user-select: none
}

.md-search-result__item {
    box-shadow: 0 -0.0625rem var(--md-default-fg-color--lightest)
}

.md-search-result__item:first-child {
    box-shadow: none
}

.md-search-result__link {
    display: block;
    outline: none;
    scroll-snap-align: start;
    transition: background-color .25s
}

.md-search-result__link:focus,.md-search-result__link:hover {
    background-color: var(--md-accent-fg-color--transparent)
}

.md-search-result__link:last-child p:last-child {
    margin-bottom: 0.75rem
}

.md-search-result__more>summary {
    cursor: pointer;
    display: block;
    outline: none;
    position: sticky;
    scroll-snap-align: start;
    top: 0;
    z-index: 1
}

.md-search-result__more>summary::marker {
    display: none
}

.md-search-result__more>summary::-webkit-details-marker {
    display: none
}

.md-search-result__more>summary>div {
    color: var(--md-typeset-a-color);
    font-size: 0.8rem;
    padding: .75em 1rem;
    transition: color .25s,background-color .25s
}

@media screen and (min-width: 60em) {
    [dir=ltr] .md-search-result__more>summary>div {
        padding-left:2.75rem
    }

    [dir=rtl] .md-search-result__more>summary>div {
        padding-right: 2.75rem
    }
}

.md-search-result__more>summary:focus>div,.md-search-result__more>summary:hover>div {
    background-color: var(--md-accent-fg-color--transparent);
    color: var(--md-accent-fg-color)
}

.md-search-result__more[open]>summary {
    background-color: var(--md-default-bg-color)
}

.md-search-result__article {
    overflow: hidden;
    padding: 0 1rem;
    position: relative
}

@media screen and (min-width: 60em) {
    [dir=ltr] .md-search-result__article {
        padding-left:2.75rem
    }

    [dir=rtl] .md-search-result__article {
        padding-right: 2.75rem
    }
}

[dir=ltr] .md-search-result__icon {
    left: 0
}

[dir=rtl] .md-search-result__icon {
    right: 0
}

.md-search-result__icon {
    color: var(--md-default-fg-color--light);
    height: 1.5rem;
    margin: 0.625rem;
    position: absolute;
    width: 1.5rem
}

@media screen and (max-width: 59.9375em) {
    .md-search-result__icon {
        display:none
    }
}

.md-search-result__icon:after {
    background-color: currentcolor;
    content: "";
    display: inline-block;
    height: 100%;
    -webkit-mask-image: var(--md-search-result-icon);
    mask-image: var(--md-search-result-icon);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    width: 100%
}

[dir=rtl] .md-search-result__icon:after {
    transform: scaleX(-1)
}

.md-search-result .md-typeset {
    color: var(--md-default-fg-color--light);
    font-size: 0.8rem;
    line-height: 1.6
}

.md-search-result .md-typeset h1 {
    color: var(--md-default-fg-color);
    font-size: 1rem;
    font-weight: 400;
    line-height: 1.4;
    margin: 0.6875rem 0
}

.md-search-result .md-typeset h1 mark {
    text-decoration: none
}

.md-search-result .md-typeset h2 {
    color: var(--md-default-fg-color);
    font-size: 0.8rem;
    font-weight: 700;
    line-height: 1.6;
    margin: .5em 0
}

.md-search-result .md-typeset h2 mark {
    text-decoration: none
}

.md-search-result__terms {
    color: var(--md-default-fg-color);
    display: block;
    font-size: 0.8rem;
    font-style: italic;
    margin: .5em 0
}

.md-search-result mark {
    background-color: initial;
    color: var(--md-accent-fg-color);
    text-decoration: underline
}

.md-select {
    position: relative;
    z-index: 1
}

.md-select__inner {
    background-color: var(--md-default-bg-color);
    border-radius: 0.125rem;
    box-shadow: var(--md-shadow-z2);
    color: var(--md-default-fg-color);
    left: 50%;
    margin-top: 0.25rem;
    max-height: 0;
    opacity: 0;
    position: absolute;
    top: calc(100% - 0.25rem);
    transform: translate3d(-50%,0.375rem,0);
    transition: transform .25s 375ms,opacity .25s .25s,max-height 0ms .5s
}

.md-select:focus-within .md-select__inner,.md-select:hover .md-select__inner {
    max-height: 12.5rem;
    opacity: 1;
    transform: translate3d(-50%,0,0);
    transition: transform .25s cubic-bezier(.1,.7,.1,1),opacity .25s,max-height 0ms
}

.md-select__inner:after {
    border-bottom: 0.25rem solid #0000;
    border-bottom-color: var(--md-default-bg-color);
    border-left: 0.25rem solid #0000;
    border-right: 0.25rem solid #0000;
    border-top: 0;
    content: "";
    height: 0;
    left: 50%;
    margin-left: -0.25rem;
    margin-top: -0.25rem;
    position: absolute;
    top: 0;
    width: 0
}

.md-select__list {
    border-radius: 0.125rem;
    font-size: 1rem;
    list-style-type: none;
    margin: 0;
    max-height: inherit;
    overflow: auto;
    padding: 0
}

.md-select__item {
    line-height: 2.25rem
}

[dir=ltr] .md-select__link {
    padding-left: 0.75rem;
    padding-right: 1.5rem
}

[dir=rtl] .md-select__link {
    padding-left: 1.5rem;
    padding-right: 0.75rem
}

.md-select__link {
    cursor: pointer;
    display: block;
    outline: none;
    scroll-snap-align: start;
    transition: background-color .25s,color .25s;
    width: 100%
}

.md-select__link:focus,.md-select__link:hover {
    color: var(--md-accent-fg-color)
}

.md-select__link:focus {
    background-color: var(--md-default-fg-color--lightest)
}

.md-sidebar {
    align-self: flex-start;
    flex-shrink: 0;
    padding: 1.5rem 0;
    position: sticky;
    top: 3rem;
    width: 15.125rem
}

@media print {
    .md-sidebar {
        display: none
    }
}

@media screen and (max-width: 76.1875em) {
    [dir=ltr] .md-sidebar--primary {
        left:-15.125rem
    }

    [dir=rtl] .md-sidebar--primary {
        right: -15.125rem
    }

    .md-sidebar--primary {
        background-color: var(--md-default-bg-color);
        display: block;
        height: 100%;
        position: fixed;
        top: 0;
        transform: translateX(0);
        transition: transform .25s cubic-bezier(.4,0,.2,1),box-shadow .25s;
        width: 15.125rem;
        z-index: 5
    }

    [data-md-toggle=drawer]:checked~.md-container .md-sidebar--primary {
        box-shadow: var(--md-shadow-z3);
        transform: translateX(15.125rem)
    }

    [dir=rtl] [data-md-toggle=drawer]:checked~.md-container .md-sidebar--primary {
        transform: translateX(-15.125rem)
    }

    .md-sidebar--primary .md-sidebar__scrollwrap {
        bottom: 0;
        left: 0;
        margin: 0;
        overflow: hidden;
        position: absolute;
        right: 0;
        scroll-snap-type: none;
        top: 0
    }
}

@media screen and (min-width: 76.25em) {
    .md-sidebar {
        height:0
    }

    .no-js .md-sidebar {
        height: auto
    }

    .md-header--lifted~.md-container .md-sidebar {
        top: 6rem
    }
}

.md-sidebar--secondary {
    display: none;
    order: 2
}

@media screen and (min-width: 60em) {
    .md-sidebar--secondary {
        height:0
    }

    .no-js .md-sidebar--secondary {
        height: auto
    }

    .md-sidebar--secondary:not([hidden]) {
        display: block
    }

    .md-sidebar--secondary .md-sidebar__scrollwrap {
        touch-action: pan-y
    }
}

.md-sidebar__scrollwrap {
    scrollbar-gutter: stable;
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden;
    margin: 0 0.25rem;
    overflow-y: auto;
    scrollbar-color: var(--md-default-fg-color--lighter) #0000;
    scrollbar-width: thin
}

.md-sidebar__scrollwrap::-webkit-scrollbar {
    height: 0.25rem;
    width: 0.25rem
}

.md-sidebar__scrollwrap:focus-within,.md-sidebar__scrollwrap:hover {
    scrollbar-color: var(--md-accent-fg-color) #0000
}

.md-sidebar__scrollwrap:focus-within::-webkit-scrollbar-thumb,.md-sidebar__scrollwrap:hover::-webkit-scrollbar-thumb {
    background-color: var(--md-default-fg-color--lighter)
}

.md-sidebar__scrollwrap:focus-within::-webkit-scrollbar-thumb:hover,.md-sidebar__scrollwrap:hover::-webkit-scrollbar-thumb:hover {
    background-color: var(--md-accent-fg-color)
}

@supports selector(::-webkit-scrollbar) {
    .md-sidebar__scrollwrap {
        scrollbar-gutter: auto
    }

    [dir=ltr] .md-sidebar__inner {
        padding-right: calc(100% - 14.375rem)
    }

    [dir=rtl] .md-sidebar__inner {
        padding-left: calc(100% - 14.375rem)
    }
}

@media screen and (max-width: 76.1875em) {
    .md-overlay {
        background-color:#0000008a;
        height: 0;
        opacity: 0;
        position: fixed;
        top: 0;
        transition: width 0ms .25s,height 0ms .25s,opacity .25s;
        width: 0;
        z-index: 5
    }

    [data-md-toggle=drawer]:checked~.md-overlay {
        height: 100%;
        opacity: 1;
        transition: width 0ms,height 0ms,opacity .25s;
        width: 100%
    }
}

@keyframes facts {
    0% {
        height: 0
    }

    to {
        height: 0.8125rem
    }
}

@keyframes fact {
    0% {
        opacity: 0;
        transform: translateY(100%)
    }

    50% {
        opacity: 0
    }

    to {
        opacity: 1;
        transform: translateY(0)
    }
}

:root {
    --md-source-forks-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M5 5.372v.878c0 .414.336.75.75.75h4.5a.75.75 0 0 0 .75-.75v-.878a2.25 2.25 0 1 1 1.5 0v.878a2.25 2.25 0 0 1-2.25 2.25h-1.5v2.128a2.251 2.251 0 1 1-1.5 0V8.5h-1.5A2.25 2.25 0 0 1 3.5 6.25v-.878a2.25 2.25 0 1 1 1.5 0ZM5 3.25a.75.75 0 1 0-1.5 0 .75.75 0 0 0 1.5 0Zm6.75.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5Zm-3 8.75a.75.75 0 1 0-1.5 0 .75.75 0 0 0 1.5 0Z"/></svg>');
    --md-source-repositories-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M2 2.5A2.5 2.5 0 0 1 4.5 0h8.75a.75.75 0 0 1 .75.75v12.5a.75.75 0 0 1-.75.75h-2.5a.75.75 0 0 1 0-1.5h1.75v-2h-8a1 1 0 0 0-.714 1.7.75.75 0 1 1-1.072 1.05A2.495 2.495 0 0 1 2 11.5Zm10.5-1h-8a1 1 0 0 0-1 1v6.708A2.486 2.486 0 0 1 4.5 9h8ZM5 12.25a.25.25 0 0 1 .25-.25h3.5a.25.25 0 0 1 .25.25v3.25a.25.25 0 0 1-.4.2l-1.45-1.087a.249.249 0 0 0-.3 0L5.4 15.7a.25.25 0 0 1-.4-.2Z"/></svg>');
    --md-source-stars-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M8 .25a.75.75 0 0 1 .673.418l1.882 3.815 4.21.612a.75.75 0 0 1 .416 1.279l-3.046 2.97.719 4.192a.751.751 0 0 1-1.088.791L8 12.347l-3.766 1.98a.75.75 0 0 1-1.088-.79l.72-4.194L.818 6.374a.75.75 0 0 1 .416-1.28l4.21-.611L7.327.668A.75.75 0 0 1 8 .25Zm0 2.445L6.615 5.5a.75.75 0 0 1-.564.41l-3.097.45 2.24 2.184a.75.75 0 0 1 .216.664l-.528 3.084 2.769-1.456a.75.75 0 0 1 .698 0l2.77 1.456-.53-3.084a.75.75 0 0 1 .216-.664l2.24-2.183-3.096-.45a.75.75 0 0 1-.564-.41L8 2.694Z"/></svg>');
    --md-source-version-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M1 7.775V2.75C1 1.784 1.784 1 2.75 1h5.025c.464 0 .91.184 1.238.513l6.25 6.25a1.75 1.75 0 0 1 0 2.474l-5.026 5.026a1.75 1.75 0 0 1-2.474 0l-6.25-6.25A1.752 1.752 0 0 1 1 7.775Zm1.5 0c0 .066.026.13.073.177l6.25 6.25a.25.25 0 0 0 .354 0l5.025-5.025a.25.25 0 0 0 0-.354l-6.25-6.25a.25.25 0 0 0-.177-.073H2.75a.25.25 0 0 0-.25.25ZM6 5a1 1 0 1 1 0 2 1 1 0 0 1 0-2Z"/></svg>')
}

.md-source {
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden;
    display: block;
    font-size: 0.8125rem;
    line-height: 1.2;
    outline-color: var(--md-accent-fg-color);
    transition: opacity .25s;
    white-space: nowrap
}

.md-source:hover {
    opacity: .7
}

.md-source__icon {
    display: inline-block;
    height: 3rem;
    vertical-align: middle;
    width: 2.5rem
}

[dir=ltr] .md-source__icon svg {
    margin-left: 0.75rem
}

[dir=rtl] .md-source__icon svg {
    margin-right: 0.75rem
}

.md-source__icon svg {
    margin-top: 0.75rem
}

[dir=ltr] .md-source__icon+.md-source__repository {
    padding-left: 2.5rem
}

[dir=rtl] .md-source__icon+.md-source__repository {
    padding-right: 2.5rem
}

[dir=ltr] .md-source__icon+.md-source__repository {
    margin-left: -2.5rem
}

[dir=rtl] .md-source__icon+.md-source__repository {
    margin-right: -2.5rem
}

[dir=ltr] .md-source__repository {
    margin-left: 0.75rem
}

[dir=rtl] .md-source__repository {
    margin-right: 0.75rem
}

.md-source__repository {
    display: inline-block;
    max-width: calc(100% - 1.5rem);
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: middle
}

.md-source__facts {
    display: flex;
    font-size: 0.6875rem;
    gap: 0.5rem;
    list-style-type: none;
    margin: 0.125rem 0 0;
    opacity: .75;
    overflow: hidden;
    padding: 0;
    width: 100%
}

.md-source__repository--active .md-source__facts {
    animation: facts .25s ease-in
}

.md-source__fact {
    overflow: hidden;
    text-overflow: ellipsis
}

.md-source__repository--active .md-source__fact {
    animation: fact .4s ease-out
}

[dir=ltr] .md-source__fact:before {
    margin-right: 0.125rem
}

[dir=rtl] .md-source__fact:before {
    margin-left: 0.125rem
}

.md-source__fact:before {
    background-color: currentcolor;
    content: "";
    display: inline-block;
    height: 0.75rem;
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    vertical-align: text-top;
    width: 0.75rem
}

.md-source__fact:nth-child(1n+2) {
    flex-shrink: 0
}

.md-source__fact--version:before {
    -webkit-mask-image: var(--md-source-version-icon);
    mask-image: var(--md-source-version-icon)
}

.md-source__fact--stars:before {
    -webkit-mask-image: var(--md-source-stars-icon);
    mask-image: var(--md-source-stars-icon)
}

.md-source__fact--forks:before {
    -webkit-mask-image: var(--md-source-forks-icon);
    mask-image: var(--md-source-forks-icon)
}

.md-source__fact--repositories:before {
    -webkit-mask-image: var(--md-source-repositories-icon);
    mask-image: var(--md-source-repositories-icon)
}

:root {
    --md-status: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M11 9h2V7h-2m1 13c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8m0-18A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10A10 10 0 0 0 12 2m-1 15h2v-6h-2v6Z"/></svg>');
    --md-status--new: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="m23 12-2.44-2.78.34-3.68-3.61-.82-1.89-3.18L12 3 8.6 1.54 6.71 4.72l-3.61.81.34 3.68L1 12l2.44 2.78-.34 3.69 3.61.82 1.89 3.18L12 21l3.4 1.46 1.89-3.18 3.61-.82-.34-3.68L23 12m-10 5h-2v-2h2v2m0-4h-2V7h2v6Z"/></svg>');
    --md-status--deprecated: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M9 3v1H4v2h1v13a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V6h1V4h-5V3H9m0 5h2v9H9V8m4 0h2v9h-2V8Z"/></svg>');
    --md-status--encrypted: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M12 1 3 5v6c0 5.55 3.84 10.74 9 12 5.16-1.26 9-6.45 9-12V5l-9-4m0 6c1.4 0 2.8 1.1 2.8 2.5V11c.6 0 1.2.6 1.2 1.3v3.5c0 .6-.6 1.2-1.3 1.2H9.2c-.6 0-1.2-.6-1.2-1.3v-3.5c0-.6.6-1.2 1.2-1.2V9.5C9.2 8.1 10.6 7 12 7m0 1.2c-.8 0-1.5.5-1.5 1.3V11h3V9.5c0-.8-.7-1.3-1.5-1.3Z"/></svg>')
}

.md-status {
    margin-left: 0.25rem
}

.md-status:after {
    background-color: var(--md-default-fg-color--light);
    content: "";
    display: inline-block;
    height: 1.125em;
    -webkit-mask-image: var(--md-status);
    mask-image: var(--md-status);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    vertical-align: text-bottom;
    width: 1.125em
}

.md-status:hover:after {
    background-color: currentcolor
}

.md-status--new:after {
    -webkit-mask-image: var(--md-status--new);
    mask-image: var(--md-status--new)
}

.md-status--deprecated:after {
    -webkit-mask-image: var(--md-status--deprecated);
    mask-image: var(--md-status--deprecated)
}

.md-status--encrypted:after {
    -webkit-mask-image: var(--md-status--encrypted);
    mask-image: var(--md-status--encrypted)
}

.md-tabs {
    background-color: var(--md-primary-fg-color);
    color: var(--md-primary-bg-color);
    display: block;
    line-height: 1.3;
    overflow: auto;
    width: 100%;
    z-index: 3
}

@media print {
    .md-tabs {
        display: none
    }
}

@media screen and (max-width: 76.1875em) {
    .md-tabs {
        display:none
    }
}

.md-tabs[hidden] {
    pointer-events: none
}

[dir=ltr] .md-tabs__list {
    margin-left: 0.25rem
}

[dir=rtl] .md-tabs__list {
    margin-right: 0.25rem
}

.md-tabs__list {
    contain: content;
    display: flex;
    list-style: none;
    margin: 0;
    overflow: auto;
    padding: 0;
    scrollbar-width: none;
    white-space: nowrap
}

.md-tabs__list::-webkit-scrollbar {
    display: none
}

.md-tabs__item {
    height: 3rem;
    padding-left: 0.75rem;
    padding-right: 0.75rem
}

.md-tabs__item--active .md-tabs__link {
    color: inherit;
    opacity: 1
}

.md-tabs__link {
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden;
    display: flex;
    font-size: 0.875rem;
    margin-top: 1rem;
    opacity: .7;
    outline-color: var(--md-accent-fg-color);
    outline-offset: 0.25rem;
    transition: transform .4s cubic-bezier(.1,.7,.1,1),opacity .25s
}

.md-tabs__link:focus,.md-tabs__link:hover {
    color: inherit;
    opacity: 1
}

[dir=ltr] .md-tabs__link svg {
    margin-right: 0.5rem
}

[dir=rtl] .md-tabs__link svg {
    margin-left: 0.5rem
}

.md-tabs__link svg {
    fill: currentcolor;
    height: 1.3em
}

.md-tabs__item:nth-child(2) .md-tabs__link {
    transition-delay: 20ms
}

.md-tabs__item:nth-child(3) .md-tabs__link {
    transition-delay: 40ms
}

.md-tabs__item:nth-child(4) .md-tabs__link {
    transition-delay: 60ms
}

.md-tabs__item:nth-child(5) .md-tabs__link {
    transition-delay: 80ms
}

.md-tabs__item:nth-child(6) .md-tabs__link {
    transition-delay: .1s
}

.md-tabs__item:nth-child(7) .md-tabs__link {
    transition-delay: .12s
}

.md-tabs__item:nth-child(8) .md-tabs__link {
    transition-delay: .14s
}

.md-tabs__item:nth-child(9) .md-tabs__link {
    transition-delay: .16s
}

.md-tabs__item:nth-child(10) .md-tabs__link {
    transition-delay: .18s
}

.md-tabs__item:nth-child(11) .md-tabs__link {
    transition-delay: .2s
}

.md-tabs__item:nth-child(12) .md-tabs__link {
    transition-delay: .22s
}

.md-tabs__item:nth-child(13) .md-tabs__link {
    transition-delay: .24s
}

.md-tabs__item:nth-child(14) .md-tabs__link {
    transition-delay: .26s
}

.md-tabs__item:nth-child(15) .md-tabs__link {
    transition-delay: .28s
}

.md-tabs__item:nth-child(16) .md-tabs__link {
    transition-delay: .3s
}

.md-tabs[hidden] .md-tabs__link {
    opacity: 0;
    transform: translateY(50%);
    transition: transform 0ms .1s,opacity .1s
}

:root {
    --md-tag-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="m5.41 21 .71-4h-4l.35-2h4l1.06-6h-4l.35-2h4l.71-4h2l-.71 4h6l.71-4h2l-.71 4h4l-.35 2h-4l-1.06 6h4l-.35 2h-4l-.71 4h-2l.71-4h-6l-.71 4h-2M9.53 9l-1.06 6h6l1.06-6h-6Z"/></svg>')
}

.md-typeset .md-tags {
    margin-bottom: .75em;
    margin-top: -.125em
}

[dir=ltr] .md-typeset .md-tag {
    margin-right: .5em
}

[dir=rtl] .md-typeset .md-tag {
    margin-left: .5em
}

.md-typeset .md-tag {
    background: var(--md-default-fg-color--lightest);
    border-radius: 3rem;
    display: inline-block;
    font-size: 0.8rem;
    font-weight: 700;
    letter-spacing: normal;
    line-height: 1.6;
    margin-bottom: .5em;
    padding: .3125em .9375em;
    vertical-align: middle
}

.md-typeset .md-tag[href] {
    -webkit-tap-highlight-color: transparent;
    color: inherit;
    outline: none;
    transition: color 125ms,background-color 125ms
}

.md-typeset .md-tag[href]:focus,.md-typeset .md-tag[href]:hover {
    background-color: var(--md-accent-fg-color);
    color: var(--md-accent-bg-color)
}

[id]>.md-typeset .md-tag {
    vertical-align: text-top
}

.md-typeset .md-tag-icon:before {
    background-color: var(--md-default-fg-color--lighter);
    content: "";
    display: inline-block;
    height: 1.2em;
    margin-right: .4em;
    -webkit-mask-image: var(--md-tag-icon);
    mask-image: var(--md-tag-icon);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    transition: background-color 125ms;
    vertical-align: text-bottom;
    width: 1.2em
}

.md-typeset .md-tag-icon[href]:focus:before,.md-typeset .md-tag-icon[href]:hover:before {
    background-color: var(--md-accent-bg-color)
}

@keyframes pulse {
    0% {
        transform: scale(.95)
    }

    75% {
        transform: scale(1)
    }

    to {
        transform: scale(.95)
    }
}

:root {
    --md-annotation-bg-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M12 2A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10A10 10 0 0 0 12 2Z"/></svg>');
    --md-annotation-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M17 13h-4v4h-2v-4H7v-2h4V7h2v4h4m-5-9A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10A10 10 0 0 0 12 2Z"/></svg>');
    --md-tooltip-width: 25rem
}

.md-tooltip {
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden;
    background-color: var(--md-default-bg-color);
    border-radius: 0.125rem;
    box-shadow: var(--md-shadow-z2);
    color: var(--md-default-fg-color);
    font-family: var(--md-text-font-family);
    left: clamp(var(--md-tooltip-0,0rem) + 1rem,var(--md-tooltip-x),100vw + var(--md-tooltip-0,0rem) + 1rem - var(--md-tooltip-width) - 2 * 1rem);
    max-width: calc(100vw - 2rem);
    opacity: 0;
    position: absolute;
    top: var(--md-tooltip-y);
    transform: translateY(-0.5rem);
    transition: transform 0ms .25s,opacity .25s,z-index .25s;
    width: var(--md-tooltip-width);
    z-index: 0
}

.md-tooltip--active {
    opacity: 1;
    transform: translateY(0);
    transition: transform .25s cubic-bezier(.1,.7,.1,1),opacity .25s,z-index 0ms;
    z-index: 2
}

.focus-visible>.md-tooltip,.md-tooltip:target {
    outline: var(--md-accent-fg-color) auto
}

.md-tooltip__inner {
    font-size: 0.8rem;
    padding: 1rem
}

.md-tooltip__inner.md-typeset>:first-child {
    margin-top: 0
}

.md-tooltip__inner.md-typeset>:last-child {
    margin-bottom: 0
}

.md-annotation {
    font-weight: 400;
    outline: none;
    vertical-align: text-bottom;
    white-space: normal
}

[dir=rtl] .md-annotation {
    direction: rtl
}

code .md-annotation {
    font-family: var(--md-code-font-family);
    font-size: inherit
}

.md-annotation:not([hidden]) {
    display: inline-block;
    line-height: 1.25
}

.md-annotation__index {
    border-radius: .01px;
    cursor: pointer;
    display: inline-block;
    margin-left: .4ch;
    margin-right: .4ch;
    outline: none;
    overflow: hidden;
    position: relative;
    -webkit-user-select: none;
    user-select: none;
    vertical-align: text-top;
    z-index: 0
}

.md-annotation .md-annotation__index {
    transition: z-index .25s
}

@media screen {
    .md-annotation__index {
        width: 2.2ch
    }

    [data-md-visible]>.md-annotation__index {
        animation: pulse 2s infinite
    }

    .md-annotation__index:before {
        background: var(--md-default-bg-color);
        -webkit-mask-image: var(--md-annotation-bg-icon);
        mask-image: var(--md-annotation-bg-icon)
    }

    .md-annotation__index:after,.md-annotation__index:before {
        content: "";
        height: 2.2ch;
        -webkit-mask-position: center;
        mask-position: center;
        -webkit-mask-repeat: no-repeat;
        mask-repeat: no-repeat;
        -webkit-mask-size: contain;
        mask-size: contain;
        position: absolute;
        top: -.1ch;
        width: 2.2ch;
        z-index: -1
    }

    .md-annotation__index:after {
        background-color: var(--md-default-fg-color--lighter);
        -webkit-mask-image: var(--md-annotation-icon);
        mask-image: var(--md-annotation-icon);
        transform: scale(1.0001);
        transition: background-color .25s,transform .25s
    }

    .md-tooltip--active+.md-annotation__index:after {
        transform: rotate(45deg)
    }

    .md-tooltip--active+.md-annotation__index:after,:hover>.md-annotation__index:after {
        background-color: var(--md-accent-fg-color)
    }
}

.md-tooltip--active+.md-annotation__index {
    animation-play-state: paused;
    transition-duration: 0ms;
    z-index: 2
}

.md-annotation__index [data-md-annotation-id] {
    display: inline-block
}

@media print {
    .md-annotation__index [data-md-annotation-id] {
        background: var(--md-default-fg-color--lighter);
        border-radius: 2ch;
        color: var(--md-default-bg-color);
        font-weight: 700;
        padding: 0 .6ch;
        white-space: nowrap
    }

    .md-annotation__index [data-md-annotation-id]:after {
        content: attr(data-md-annotation-id)
    }
}

.md-typeset .md-annotation-list {
    counter-reset: xxx;
    list-style: none
}

.md-typeset .md-annotation-list li {
    position: relative
}

[dir=ltr] .md-typeset .md-annotation-list li:before {
    left: -2.125em
}

[dir=rtl] .md-typeset .md-annotation-list li:before {
    right: -2.125em
}

.md-typeset .md-annotation-list li:before {
    background: var(--md-default-fg-color--lighter);
    border-radius: 2ch;
    color: var(--md-default-bg-color);
    content: counter(xxx);
    counter-increment: xxx;
    font-size: .8875em;
    font-weight: 700;
    height: 2ch;
    line-height: 1.25;
    min-width: 2ch;
    padding: 0 .6ch;
    position: absolute;
    text-align: center;
    top: .25em
}

[dir=ltr] .md-top {
    margin-left: 50%
}

[dir=rtl] .md-top {
    margin-right: 50%
}

.md-top {
    background-color: var(--md-default-bg-color);
    border-radius: 2rem;
    box-shadow: var(--md-shadow-z2);
    color: var(--md-default-fg-color--light);
    cursor: pointer;
    display: block;
    font-size: 0.875rem;
    outline: none;
    padding: 0.5rem 1rem;
    position: fixed;
    top: 4rem;
    transform: translate(-50%);
    transition: color 125ms,background-color 125ms,transform 125ms cubic-bezier(.4,0,.2,1),opacity 125ms;
    z-index: 2
}

@media print {
    .md-top {
        display: none
    }
}

[dir=rtl] .md-top {
    transform: translate(50%)
}

.md-top[hidden] {
    opacity: 0;
    pointer-events: none;
    transform: translate(-50%,0.25rem);
    transition-duration: 0ms
}

[dir=rtl] .md-top[hidden] {
    transform: translate(50%,0.25rem)
}

.md-top:focus,.md-top:hover {
    background-color: var(--md-accent-fg-color);
    color: var(--md-accent-bg-color)
}

.md-top svg {
    display: inline-block;
    vertical-align: -.5em
}

@keyframes hoverfix {
    0% {
        pointer-events: none
    }
}

:root {
    --md-version-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512"><!--! Font Awesome Free 6.4.2 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License) Copyright 2023 Fonticons, Inc.--><path d="M137.4 374.6c12.5 12.5 32.8 12.5 45.3 0l128-128c9.2-9.2 11.9-22.9 6.9-34.9S301 191.9 288 191.9L32 192c-12.9 0-24.6 7.8-29.6 19.8s-2.2 25.7 6.9 34.9l128 128z"/></svg>')
}

.md-version {
    flex-shrink: 0;
    font-size: 1rem;
    height: 3rem
}

[dir=ltr] .md-version__current {
    margin-left: 1.75rem;
    margin-right: 0.5rem
}

[dir=rtl] .md-version__current {
    margin-left: 0.5rem;
    margin-right: 1.75rem
}

.md-version__current {
    color: inherit;
    cursor: pointer;
    outline: none;
    position: relative;
    top: 0.0625rem
}

[dir=ltr] .md-version__current:after {
    margin-left: 0.5rem
}

[dir=rtl] .md-version__current:after {
    margin-right: 0.5rem
}

.md-version__current:after {
    background-color: currentcolor;
    content: "";
    display: inline-block;
    height: 0.75rem;
    -webkit-mask-image: var(--md-version-icon);
    mask-image: var(--md-version-icon);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    width: 0.5rem
}

.md-version__list {
    background-color: var(--md-default-bg-color);
    border-radius: 0.125rem;
    box-shadow: var(--md-shadow-z2);
    color: var(--md-default-fg-color);
    list-style-type: none;
    margin: 0.25rem 1rem;
    max-height: 0;
    opacity: 0;
    overflow: auto;
    padding: 0;
    position: absolute;
    scroll-snap-type: y mandatory;
    top: 0.1875rem;
    transition: max-height 0ms .5s,opacity .25s .25s;
    z-index: 3
}

.md-version:focus-within .md-version__list,.md-version:hover .md-version__list {
    max-height: 12.5rem;
    opacity: 1;
    transition: max-height 0ms,opacity .25s
}

@media (hover: none),(pointer:coarse) {
    .md-version:hover .md-version__list {
        animation:hoverfix .25s forwards
    }

    .md-version:focus-within .md-version__list {
        animation: none
    }
}

.md-version__item {
    line-height: 2.25rem
}

[dir=ltr] .md-version__link {
    padding-left: 0.75rem;
    padding-right: 1.5rem
}

[dir=rtl] .md-version__link {
    padding-left: 1.5rem;
    padding-right: 0.75rem
}

.md-version__link {
    cursor: pointer;
    display: block;
    outline: none;
    scroll-snap-align: start;
    transition: color .25s,background-color .25s;
    white-space: nowrap;
    width: 100%
}

.md-version__link:focus,.md-version__link:hover {
    color: var(--md-accent-fg-color)
}

.md-version__link:focus {
    background-color: var(--md-default-fg-color--lightest)
}

:root {
    --md-admonition-icon--note: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M12 2C6.47 2 2 6.47 2 12s4.47 10 10 10 10-4.47 10-10S17.53 2 12 2m3.1 5.07c.14 0 .28.05.4.16l1.27 1.27c.23.22.23.57 0 .78l-1 1-2.05-2.05 1-1c.1-.11.24-.16.38-.16m-1.97 1.74 2.06 2.06-6.06 6.06H7.07v-2.06l6.06-6.06Z"/></svg>');
    --md-admonition-icon--abstract: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M17 9H7V7h10m0 6H7v-2h10m-3 6H7v-2h7M12 3a1 1 0 0 1 1 1 1 1 0 0 1-1 1 1 1 0 0 1-1-1 1 1 0 0 1 1-1m7 0h-4.18C14.4 1.84 13.3 1 12 1c-1.3 0-2.4.84-2.82 2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2Z"/></svg>');
    --md-admonition-icon--info: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M13 9h-2V7h2m0 10h-2v-6h2m-1-9A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10A10 10 0 0 0 12 2Z"/></svg>');
    --md-admonition-icon--tip: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27Z"/></svg>');
    --md-admonition-icon--success: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M21 7 9 19l-5.5-5.5 1.41-1.41L9 16.17 19.59 5.59 21 7Z"/></svg>');
    --md-admonition-icon--question: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="m15.07 11.25-.9.92C13.45 12.89 13 13.5 13 15h-2v-.5c0-1.11.45-2.11 1.17-2.83l1.24-1.26c.37-.36.59-.86.59-1.41a2 2 0 0 0-2-2 2 2 0 0 0-2 2H8a4 4 0 0 1 4-4 4 4 0 0 1 4 4 3.2 3.2 0 0 1-.93 2.25M13 19h-2v-2h2M12 2A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10c0-5.53-4.5-10-10-10Z"/></svg>');
    --md-admonition-icon--warning: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M13 14h-2V9h2m0 9h-2v-2h2M1 21h22L12 2 1 21Z"/></svg>');
    --md-admonition-icon--failure: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M19 6.41 17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12 19 6.41Z"/></svg>');
    --md-admonition-icon--danger: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="m11.5 20 4.86-9.73H13V4l-5 9.73h3.5V20M12 2c2.75 0 5.1 1 7.05 2.95C21 6.9 22 9.25 22 12s-1 5.1-2.95 7.05C17.1 21 14.75 22 12 22s-5.1-1-7.05-2.95C3 17.1 2 14.75 2 12s1-5.1 2.95-7.05C6.9 3 9.25 2 12 2Z"/></svg>');
    --md-admonition-icon--bug: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M11 13h2v1h-2v-1m10-8v6c0 5.5-3.8 10.7-9 12-5.2-1.3-9-6.5-9-12V5l9-4 9 4m-4 5h-2.2c-.2-.6-.6-1.1-1.1-1.5l1.2-1.2-.7-.7L12.8 8H12c-.2 0-.5 0-.7.1L9.9 6.6l-.8.8 1.2 1.2c-.5.3-.9.8-1.1 1.4H7v1h2v1H7v1h2v1H7v1h2.2c.4 1.2 1.5 2 2.8 2s2.4-.8 2.8-2H17v-1h-2v-1h2v-1h-2v-1h2v-1m-6 2h2v-1h-2v1Z"/></svg>');
    --md-admonition-icon--example: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M7 2v2h1v14a4 4 0 0 0 4 4 4 4 0 0 0 4-4V4h1V2H7m4 14c-.6 0-1-.4-1-1s.4-1 1-1 1 .4 1 1-.4 1-1 1m2-4c-.6 0-1-.4-1-1s.4-1 1-1 1 .4 1 1-.4 1-1 1m1-5h-4V4h4v3Z"/></svg>');
    --md-admonition-icon--quote: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M14 17h3l2-4V7h-6v6h3M6 17h3l2-4V7H5v6h3l-2 4Z"/></svg>')
}

.md-typeset .admonition,.md-typeset details {
    background-color: var(--md-admonition-bg-color);
    border: 0.0625rem solid #448aff;
    border-radius: 0.25rem;
    box-shadow: var(--md-shadow-z1);
    color: var(--md-admonition-fg-color);
    display: flow-root;
    font-size: 0.8rem;
    margin: 1.5625em 0;
    padding: 0 0.75rem;
    page-break-inside: avoid;
    transition: box-shadow 125ms
}

@media print {
    .md-typeset .admonition,.md-typeset details {
        box-shadow: none
    }
}

.md-typeset .admonition:focus-within,.md-typeset details:focus-within {
    box-shadow: 0 0 0 0.25rem #448aff1a
}

.md-typeset .admonition>*,.md-typeset details>* {
    box-sizing: border-box
}

.md-typeset .admonition .admonition,.md-typeset .admonition details,.md-typeset details .admonition,.md-typeset details details {
    margin-bottom: 1em;
    margin-top: 1em
}

.md-typeset .admonition .md-typeset__scrollwrap,.md-typeset details .md-typeset__scrollwrap {
    margin: 1em -0.75rem
}

.md-typeset .admonition .md-typeset__table,.md-typeset details .md-typeset__table {
    padding: 0 0.75rem
}

.md-typeset .admonition>.tabbed-set:only-child,.md-typeset details>.tabbed-set:only-child {
    margin-top: 0
}

html .md-typeset .admonition>:last-child,html .md-typeset details>:last-child {
    margin-bottom: 0.75rem
}

[dir=ltr] .md-typeset .admonition-title,[dir=ltr] .md-typeset summary {
    padding-left: 2.5rem;
    padding-right: 0.75rem
}

[dir=rtl] .md-typeset .admonition-title,[dir=rtl] .md-typeset summary {
    padding-left: 0.75rem;
    padding-right: 2.5rem
}

[dir=ltr] .md-typeset .admonition-title,[dir=ltr] .md-typeset summary {
    border-left-width: 0.25rem
}

[dir=rtl] .md-typeset .admonition-title,[dir=rtl] .md-typeset summary {
    border-right-width: 0.25rem
}

[dir=ltr] .md-typeset .admonition-title,[dir=ltr] .md-typeset summary {
    border-top-left-radius: 0.125rem
}

[dir=ltr] .md-typeset .admonition-title,[dir=ltr] .md-typeset summary,[dir=rtl] .md-typeset .admonition-title,[dir=rtl] .md-typeset summary {
    border-top-right-radius: 0.125rem
}

[dir=rtl] .md-typeset .admonition-title,[dir=rtl] .md-typeset summary {
    border-top-left-radius: 0.125rem
}

.md-typeset .admonition-title,.md-typeset summary {
    background-color: #448aff1a;
    border: none;
    font-weight: 700;
    margin: 0 -0.75rem;
    padding-bottom: 0.5rem;
    padding-top: 0.5rem;
    position: relative
}

html .md-typeset .admonition-title:last-child,html .md-typeset summary:last-child {
    margin-bottom: 0
}

[dir=ltr] .md-typeset .admonition-title:before,[dir=ltr] .md-typeset summary:before {
    left: 0.75rem
}

[dir=rtl] .md-typeset .admonition-title:before,[dir=rtl] .md-typeset summary:before {
    right: 0.75rem
}

.md-typeset .admonition-title:before,.md-typeset summary:before {
    background-color: #448aff;
    content: "";
    height: 1.25rem;
    -webkit-mask-image: var(--md-admonition-icon--note);
    mask-image: var(--md-admonition-icon--note);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    position: absolute;
    top: .625em;
    width: 1.25rem
}

.md-typeset .admonition-title code,.md-typeset summary code {
    box-shadow: 0 0 0 0.0625rem var(--md-default-fg-color--lightest)
}

.md-typeset .admonition.note,.md-typeset details.note {
    border-color: #448aff
}

.md-typeset .admonition.note:focus-within,.md-typeset details.note:focus-within {
    box-shadow: 0 0 0 0.25rem #448aff1a
}

.md-typeset .note>.admonition-title,.md-typeset .note>summary {
    background-color: #448aff1a
}

.md-typeset .note>.admonition-title:before,.md-typeset .note>summary:before {
    background-color: #448aff;
    -webkit-mask-image: var(--md-admonition-icon--note);
    mask-image: var(--md-admonition-icon--note)
}

.md-typeset .note>.admonition-title:after,.md-typeset .note>summary:after {
    color: #448aff
}

.md-typeset .admonition.abstract,.md-typeset details.abstract {
    border-color: #00b0ff
}

.md-typeset .admonition.abstract:focus-within,.md-typeset details.abstract:focus-within {
    box-shadow: 0 0 0 0.25rem #00b0ff1a
}

.md-typeset .abstract>.admonition-title,.md-typeset .abstract>summary {
    background-color: #00b0ff1a
}

.md-typeset .abstract>.admonition-title:before,.md-typeset .abstract>summary:before {
    background-color: #00b0ff;
    -webkit-mask-image: var(--md-admonition-icon--abstract);
    mask-image: var(--md-admonition-icon--abstract)
}

.md-typeset .abstract>.admonition-title:after,.md-typeset .abstract>summary:after {
    color: #00b0ff
}

.md-typeset .admonition.info,.md-typeset details.info {
    border-color: #00b8d4
}

.md-typeset .admonition.info:focus-within,.md-typeset details.info:focus-within {
    box-shadow: 0 0 0 0.25rem #00b8d41a
}

.md-typeset .info>.admonition-title,.md-typeset .info>summary {
    background-color: #00b8d41a
}

.md-typeset .info>.admonition-title:before,.md-typeset .info>summary:before {
    background-color: #00b8d4;
    -webkit-mask-image: var(--md-admonition-icon--info);
    mask-image: var(--md-admonition-icon--info)
}

.md-typeset .info>.admonition-title:after,.md-typeset .info>summary:after {
    color: #00b8d4
}

.md-typeset .admonition.tip,.md-typeset details.tip {
    border-color: #00bfa5
}

.md-typeset .admonition.tip:focus-within,.md-typeset details.tip:focus-within {
    box-shadow: 0 0 0 0.25rem #00bfa51a
}

.md-typeset .tip>.admonition-title,.md-typeset .tip>summary {
    background-color: #00bfa51a
}

.md-typeset .tip>.admonition-title:before,.md-typeset .tip>summary:before {
    background-color: #00bfa5;
    -webkit-mask-image: var(--md-admonition-icon--tip);
    mask-image: var(--md-admonition-icon--tip)
}

.md-typeset .tip>.admonition-title:after,.md-typeset .tip>summary:after {
    color: #00bfa5
}

.md-typeset .admonition.success,.md-typeset details.success {
    border-color: #00c853
}

.md-typeset .admonition.success:focus-within,.md-typeset details.success:focus-within {
    box-shadow: 0 0 0 0.25rem #00c8531a
}

.md-typeset .success>.admonition-title,.md-typeset .success>summary {
    background-color: #00c8531a
}

.md-typeset .success>.admonition-title:before,.md-typeset .success>summary:before {
    background-color: #00c853;
    -webkit-mask-image: var(--md-admonition-icon--success);
    mask-image: var(--md-admonition-icon--success)
}

.md-typeset .success>.admonition-title:after,.md-typeset .success>summary:after {
    color: #00c853
}

.md-typeset .admonition.question,.md-typeset details.question {
    border-color: #64dd17
}

.md-typeset .admonition.question:focus-within,.md-typeset details.question:focus-within {
    box-shadow: 0 0 0 0.25rem #64dd171a
}

.md-typeset .question>.admonition-title,.md-typeset .question>summary {
    background-color: #64dd171a
}

.md-typeset .question>.admonition-title:before,.md-typeset .question>summary:before {
    background-color: #64dd17;
    -webkit-mask-image: var(--md-admonition-icon--question);
    mask-image: var(--md-admonition-icon--question)
}

.md-typeset .question>.admonition-title:after,.md-typeset .question>summary:after {
    color: #64dd17
}

.md-typeset .admonition.warning,.md-typeset details.warning {
    border-color: #ff9100
}

.md-typeset .admonition.warning:focus-within,.md-typeset details.warning:focus-within {
    box-shadow: 0 0 0 0.25rem #ff91001a
}

.md-typeset .warning>.admonition-title,.md-typeset .warning>summary {
    background-color: #ff91001a
}

.md-typeset .warning>.admonition-title:before,.md-typeset .warning>summary:before {
    background-color: #ff9100;
    -webkit-mask-image: var(--md-admonition-icon--warning);
    mask-image: var(--md-admonition-icon--warning)
}

.md-typeset .warning>.admonition-title:after,.md-typeset .warning>summary:after {
    color: #ff9100
}

.md-typeset .admonition.failure,.md-typeset details.failure {
    border-color: #ff5252
}

.md-typeset .admonition.failure:focus-within,.md-typeset details.failure:focus-within {
    box-shadow: 0 0 0 0.25rem #ff52521a
}

.md-typeset .failure>.admonition-title,.md-typeset .failure>summary {
    background-color: #ff52521a
}

.md-typeset .failure>.admonition-title:before,.md-typeset .failure>summary:before {
    background-color: #ff5252;
    -webkit-mask-image: var(--md-admonition-icon--failure);
    mask-image: var(--md-admonition-icon--failure)
}

.md-typeset .failure>.admonition-title:after,.md-typeset .failure>summary:after {
    color: #ff5252
}

.md-typeset .admonition.danger,.md-typeset details.danger {
    border-color: #ff1744
}

.md-typeset .admonition.danger:focus-within,.md-typeset details.danger:focus-within {
    box-shadow: 0 0 0 0.25rem #ff17441a
}

.md-typeset .danger>.admonition-title,.md-typeset .danger>summary {
    background-color: #ff17441a
}

.md-typeset .danger>.admonition-title:before,.md-typeset .danger>summary:before {
    background-color: #ff1744;
    -webkit-mask-image: var(--md-admonition-icon--danger);
    mask-image: var(--md-admonition-icon--danger)
}

.md-typeset .danger>.admonition-title:after,.md-typeset .danger>summary:after {
    color: #ff1744
}

.md-typeset .admonition.bug,.md-typeset details.bug {
    border-color: #f50057
}

.md-typeset .admonition.bug:focus-within,.md-typeset details.bug:focus-within {
    box-shadow: 0 0 0 0.25rem #f500571a
}

.md-typeset .bug>.admonition-title,.md-typeset .bug>summary {
    background-color: #f500571a
}

.md-typeset .bug>.admonition-title:before,.md-typeset .bug>summary:before {
    background-color: #f50057;
    -webkit-mask-image: var(--md-admonition-icon--bug);
    mask-image: var(--md-admonition-icon--bug)
}

.md-typeset .bug>.admonition-title:after,.md-typeset .bug>summary:after {
    color: #f50057
}

.md-typeset .admonition.example,.md-typeset details.example {
    border-color: #7c4dff
}

.md-typeset .admonition.example:focus-within,.md-typeset details.example:focus-within {
    box-shadow: 0 0 0 0.25rem #7c4dff1a
}

.md-typeset .example>.admonition-title,.md-typeset .example>summary {
    background-color: #7c4dff1a
}

.md-typeset .example>.admonition-title:before,.md-typeset .example>summary:before {
    background-color: #7c4dff;
    -webkit-mask-image: var(--md-admonition-icon--example);
    mask-image: var(--md-admonition-icon--example)
}

.md-typeset .example>.admonition-title:after,.md-typeset .example>summary:after {
    color: #7c4dff
}

.md-typeset .admonition.quote,.md-typeset details.quote {
    border-color: #9e9e9e
}

.md-typeset .admonition.quote:focus-within,.md-typeset details.quote:focus-within {
    box-shadow: 0 0 0 0.25rem #9e9e9e1a
}

.md-typeset .quote>.admonition-title,.md-typeset .quote>summary {
    background-color: #9e9e9e1a
}

.md-typeset .quote>.admonition-title:before,.md-typeset .quote>summary:before {
    background-color: #9e9e9e;
    -webkit-mask-image: var(--md-admonition-icon--quote);
    mask-image: var(--md-admonition-icon--quote)
}

.md-typeset .quote>.admonition-title:after,.md-typeset .quote>summary:after {
    color: #9e9e9e
}

:root {
    --md-footnotes-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M19 7v4H5.83l3.58-3.59L8 6l-6 6 6 6 1.41-1.42L5.83 13H21V7h-2Z"/></svg>')
}

.md-typeset .footnote {
    color: var(--md-default-fg-color--light);
    font-size: 0.8rem
}

[dir=ltr] .md-typeset .footnote>ol {
    margin-left: 0
}

[dir=rtl] .md-typeset .footnote>ol {
    margin-right: 0
}

.md-typeset .footnote>ol>li {
    transition: color 125ms
}

.md-typeset .footnote>ol>li:target {
    color: var(--md-default-fg-color)
}

.md-typeset .footnote>ol>li:focus-within .footnote-backref {
    opacity: 1;
    transform: translateX(0);
    transition: none
}

.md-typeset .footnote>ol>li:hover .footnote-backref,.md-typeset .footnote>ol>li:target .footnote-backref {
    opacity: 1;
    transform: translateX(0)
}

.md-typeset .footnote>ol>li>:first-child {
    margin-top: 0
}

.md-typeset .footnote-ref {
    font-size: .75em;
    font-weight: 700
}

html .md-typeset .footnote-ref {
    outline-offset: 0.125rem
}

.md-typeset [id^="fnref:"]:target>.footnote-ref {
    outline: auto
}

.md-typeset .footnote-backref {
    color: var(--md-typeset-a-color);
    display: inline-block;
    font-size: 0;
    opacity: 0;
    transform: translateX(0.3125rem);
    transition: color .25s,transform .25s .25s,opacity 125ms .25s;
    vertical-align: text-bottom
}

@media print {
    .md-typeset .footnote-backref {
        color: var(--md-typeset-a-color);
        opacity: 1;
        transform: translateX(0)
    }
}

[dir=rtl] .md-typeset .footnote-backref {
    transform: translateX(-0.3125rem)
}

.md-typeset .footnote-backref:hover {
    color: var(--md-accent-fg-color)
}

.md-typeset .footnote-backref:before {
    background-color: currentcolor;
    content: "";
    display: inline-block;
    height: 1rem;
    -webkit-mask-image: var(--md-footnotes-icon);
    mask-image: var(--md-footnotes-icon);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    width: 1rem
}

[dir=rtl] .md-typeset .footnote-backref:before svg {
    transform: scaleX(-1)
}

[dir=ltr] .md-typeset .headerlink {
    margin-left: 0.625rem
}

[dir=rtl] .md-typeset .headerlink {
    margin-right: 0.625rem
}

.md-typeset .headerlink {
    color: var(--md-default-fg-color--lighter);
    display: inline-block;
    opacity: 0;
    transition: color .25s,opacity 125ms
}

@media print {
    .md-typeset .headerlink {
        display: none
    }
}

.md-typeset .headerlink:focus,.md-typeset :hover>.headerlink,.md-typeset :target>.headerlink {
    opacity: 1;
    transition: color .25s,opacity 125ms
}

.md-typeset .headerlink:focus,.md-typeset .headerlink:hover,.md-typeset :target>.headerlink {
    color: var(--md-accent-fg-color)
}

.md-typeset :target {
    --md-scroll-margin: 4.5rem;
    --md-scroll-offset: 0rem;
    scroll-margin-top: calc(var(--md-scroll-margin) - var(--md-scroll-offset))
}

@media screen and (min-width: 76.25em) {
    .md-header--lifted~.md-container .md-typeset :target {
        --md-scroll-margin:7.5rem
    }
}

.md-typeset h1:target,.md-typeset h2:target,.md-typeset h3:target {
    --md-scroll-offset: 0.25rem
}

.md-typeset h4:target {
    --md-scroll-offset: 0.1875rem
}

.md-typeset div.arithmatex {
    overflow: auto
}

@media screen and (max-width: 44.9375em) {
    .md-typeset div.arithmatex {
        margin:0 -1rem
    }
}

.md-typeset div.arithmatex>* {
    margin-left: auto!important;
    margin-right: auto!important;
    padding: 0 1rem;
    touch-action: auto;
    width: -webkit-min-content;
    width: min-content
}

.md-typeset div.arithmatex>* mjx-container {
    margin: 0!important
}

.md-typeset del.critic {
    background-color: var(--md-typeset-del-color)
}

.md-typeset del.critic,.md-typeset ins.critic {
    -webkit-box-decoration-break: clone;
    box-decoration-break: clone
}

.md-typeset ins.critic {
    background-color: var(--md-typeset-ins-color)
}

.md-typeset .critic.comment {
    -webkit-box-decoration-break: clone;
    box-decoration-break: clone;
    color: var(--md-code-hl-comment-color)
}

.md-typeset .critic.comment:before {
    content: "/* "
}

.md-typeset .critic.comment:after {
    content: " */"
}

.md-typeset .critic.block {
    box-shadow: none;
    display: block;
    margin: 1em 0;
    overflow: auto;
    padding-left: 1rem;
    padding-right: 1rem
}

.md-typeset .critic.block>:first-child {
    margin-top: .5em
}

.md-typeset .critic.block>:last-child {
    margin-bottom: .5em
}

:root {
    --md-details-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M8.59 16.58 13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.42Z"/></svg>')
}

.md-typeset details {
    display: flow-root;
    overflow: visible;
    padding-top: 0
}

.md-typeset details[open]>summary:after {
    transform: rotate(90deg)
}

.md-typeset details:not([open]) {
    box-shadow: none;
    padding-bottom: 0
}

.md-typeset details:not([open])>summary {
    border-radius: 0.125rem
}

[dir=ltr] .md-typeset summary {
    padding-right: 2.25rem
}

[dir=rtl] .md-typeset summary {
    padding-left: 2.25rem
}

[dir=ltr] .md-typeset summary {
    border-top-left-radius: 0.125rem
}

[dir=ltr] .md-typeset summary,[dir=rtl] .md-typeset summary {
    border-top-right-radius: 0.125rem
}

[dir=rtl] .md-typeset summary {
    border-top-left-radius: 0.125rem
}

.md-typeset summary {
    cursor: pointer;
    display: block;
    min-height: 1.25rem
}

.md-typeset summary.focus-visible {
    outline-color: var(--md-accent-fg-color);
    outline-offset: 0.25rem
}

.md-typeset summary:not(.focus-visible) {
    -webkit-tap-highlight-color: transparent;
    outline: none
}

[dir=ltr] .md-typeset summary:after {
    right: 0.5rem
}

[dir=rtl] .md-typeset summary:after {
    left: 0.5rem
}

.md-typeset summary:after {
    background-color: currentcolor;
    content: "";
    height: 1.25rem;
    -webkit-mask-image: var(--md-details-icon);
    mask-image: var(--md-details-icon);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    position: absolute;
    top: .625em;
    transform: rotate(0deg);
    transition: transform .25s;
    width: 1.25rem
}

[dir=rtl] .md-typeset summary:after {
    transform: rotate(180deg)
}

.md-typeset summary::marker {
    display: none
}

.md-typeset summary::-webkit-details-marker {
    display: none
}

.md-typeset .emojione,.md-typeset .gemoji,.md-typeset .twemoji {
    display: inline-flex;
    height: 1.125em;
    vertical-align: text-top
}

.md-typeset .emojione svg,.md-typeset .gemoji svg,.md-typeset .twemoji svg {
    fill: currentcolor;
    max-height: 100%;
    width: 1.125em
}

.highlight .o,.highlight .ow {
    color: var(--md-code-hl-operator-color)
}

.highlight .p {
    color: var(--md-code-hl-punctuation-color)
}

.highlight .cpf,.highlight .l,.highlight .s,.highlight .s1,.highlight .s2,.highlight .sb,.highlight .sc,.highlight .si,.highlight .ss {
    color: var(--md-code-hl-string-color)
}

.highlight .cp,.highlight .se,.highlight .sh,.highlight .sr,.highlight .sx {
    color: var(--md-code-hl-special-color)
}

.highlight .il,.highlight .m,.highlight .mb,.highlight .mf,.highlight .mh,.highlight .mi,.highlight .mo {
    color: var(--md-code-hl-number-color)
}

.highlight .k,.highlight .kd,.highlight .kn,.highlight .kp,.highlight .kr,.highlight .kt {
    color: var(--md-code-hl-keyword-color)
}

.highlight .kc,.highlight .n {
    color: var(--md-code-hl-name-color)
}

.highlight .bp,.highlight .nb,.highlight .no {
    color: var(--md-code-hl-constant-color)
}

.highlight .nc,.highlight .ne,.highlight .nf,.highlight .nn {
    color: var(--md-code-hl-function-color)
}

.highlight .nd,.highlight .ni,.highlight .nl,.highlight .nt {
    color: var(--md-code-hl-keyword-color)
}

.highlight .c,.highlight .c1,.highlight .ch,.highlight .cm,.highlight .cs,.highlight .sd {
    color: var(--md-code-hl-comment-color)
}

.highlight .na,.highlight .nv,.highlight .vc,.highlight .vg,.highlight .vi {
    color: var(--md-code-hl-variable-color)
}

.highlight .ge,.highlight .gh,.highlight .go,.highlight .gp,.highlight .gr,.highlight .gs,.highlight .gt,.highlight .gu {
    color: var(--md-code-hl-generic-color)
}

.highlight .gd,.highlight .gi {
    border-radius: 0.125rem;
    margin: 0 -.125em;
    padding: 0 .125em
}

.highlight .gd {
    background-color: var(--md-typeset-del-color)
}

.highlight .gi {
    background-color: var(--md-typeset-ins-color)
}

.highlight .hll {
    background-color: var(--md-code-hl-color);
    display: block;
    margin: 0 -1.1764705882em;
    padding: 0 1.1764705882em
}

.highlight span.filename {
    background-color: var(--md-code-bg-color);
    border-bottom: 0.0625rem solid var(--md-default-fg-color--lightest);
    border-top-left-radius: 0.125rem;
    border-top-right-radius: 0.125rem;
    display: flow-root;
    font-size: .85em;
    font-weight: 700;
    margin-top: 1em;
    padding: .6617647059em 1.1764705882em;
    position: relative
}

.highlight span.filename+pre {
    margin-top: 0
}

.highlight span.filename+pre>code {
    border-top-left-radius: 0;
    border-top-right-radius: 0
}

.highlight [data-linenos]:before {
    background-color: var(--md-code-bg-color);
    box-shadow: -0.0625rem 0 var(--md-default-fg-color--lightest) inset;
    color: var(--md-default-fg-color--light);
    content: attr(data-linenos);
    float: left;
    left: -1.1764705882em;
    margin-left: -1.1764705882em;
    margin-right: 1.1764705882em;
    padding-left: 1.1764705882em;
    position: sticky;
    -webkit-user-select: none;
    user-select: none;
    z-index: 3
}

.highlight code a[id] {
    position: absolute;
    visibility: hidden
}

.highlight code[data-md-copying] .hll {
    display: contents
}

.highlight code[data-md-copying] .md-annotation {
    display: none
}

.highlighttable {
    display: flow-root
}

.highlighttable tbody,.highlighttable td {
    display: block;
    padding: 0
}

.highlighttable tr {
    display: flex
}

.highlighttable pre {
    margin: 0
}

.highlighttable th.filename {
    flex-grow: 1;
    padding: 0;
    text-align: left
}

.highlighttable th.filename span.filename {
    margin-top: 0
}

.highlighttable .linenos {
    background-color: var(--md-code-bg-color);
    border-bottom-left-radius: 0.125rem;
    border-top-left-radius: 0.125rem;
    font-size: .85em;
    padding: .7720588235em 0 .7720588235em 1.1764705882em;
    -webkit-user-select: none;
    user-select: none
}

.highlighttable .linenodiv {
    box-shadow: -0.0625rem 0 var(--md-default-fg-color--lightest) inset;
    padding-right: .5882352941em
}

.highlighttable .linenodiv pre {
    color: var(--md-default-fg-color--light);
    text-align: right
}

.highlighttable .code {
    flex: 1;
    min-width: 0
}

.linenodiv a {
    color: inherit
}

.md-typeset .highlighttable {
    direction: ltr;
    margin: 1em 0
}

.md-typeset .highlighttable>tbody>tr>.code>div>pre>code {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0
}

.md-typeset .highlight+.result {
    border: 0.0625rem solid var(--md-code-bg-color);
    border-bottom-left-radius: 0.125rem;
    border-bottom-right-radius: 0.125rem;
    border-top-width: 0.125rem;
    margin-top: -1.125em;
    overflow: visible;
    padding: 0 1em
}

.md-typeset .highlight+.result:after {
    clear: both;
    content: "";
    display: block
}

@media screen and (max-width: 44.9375em) {
    .md-content__inner>.highlight {
        margin:1em -1rem
    }

    .md-content__inner>.highlight>.filename,.md-content__inner>.highlight>.highlighttable>tbody>tr>.code>div>pre>code,.md-content__inner>.highlight>.highlighttable>tbody>tr>.filename span.filename,.md-content__inner>.highlight>.highlighttable>tbody>tr>.linenos,.md-content__inner>.highlight>pre>code {
        border-radius: 0
    }

    .md-content__inner>.highlight+.result {
        border-left-width: 0;
        border-radius: 0;
        border-right-width: 0;
        margin-left: -1rem;
        margin-right: -1rem
    }
}

.md-typeset .keys kbd:after,.md-typeset .keys kbd:before {
    -moz-osx-font-smoothing: initial;
    -webkit-font-smoothing: initial;
    color: inherit;
    margin: 0;
    position: relative
}

.md-typeset .keys span {
    color: var(--md-default-fg-color--light);
    padding: 0 .2em
}

.md-typeset .keys .key-alt:before,.md-typeset .keys .key-left-alt:before,.md-typeset .keys .key-right-alt:before {
    content: "⎇";
    padding-right: .4em
}

.md-typeset .keys .key-command:before,.md-typeset .keys .key-left-command:before,.md-typeset .keys .key-right-command:before {
    content: "⌘";
    padding-right: .4em
}

.md-typeset .keys .key-control:before,.md-typeset .keys .key-left-control:before,.md-typeset .keys .key-right-control:before {
    content: "⌃";
    padding-right: .4em
}

.md-typeset .keys .key-left-meta:before,.md-typeset .keys .key-meta:before,.md-typeset .keys .key-right-meta:before {
    content: "◆";
    padding-right: .4em
}

.md-typeset .keys .key-left-option:before,.md-typeset .keys .key-option:before,.md-typeset .keys .key-right-option:before {
    content: "⌥";
    padding-right: .4em
}

.md-typeset .keys .key-left-shift:before,.md-typeset .keys .key-right-shift:before,.md-typeset .keys .key-shift:before {
    content: "⇧";
    padding-right: .4em
}

.md-typeset .keys .key-left-super:before,.md-typeset .keys .key-right-super:before,.md-typeset .keys .key-super:before {
    content: "❖";
    padding-right: .4em
}

.md-typeset .keys .key-left-windows:before,.md-typeset .keys .key-right-windows:before,.md-typeset .keys .key-windows:before {
    content: "⊞";
    padding-right: .4em
}

.md-typeset .keys .key-arrow-down:before {
    content: "↓";
    padding-right: .4em
}

.md-typeset .keys .key-arrow-left:before {
    content: "←";
    padding-right: .4em
}

.md-typeset .keys .key-arrow-right:before {
    content: "→";
    padding-right: .4em
}

.md-typeset .keys .key-arrow-up:before {
    content: "↑";
    padding-right: .4em
}

.md-typeset .keys .key-backspace:before {
    content: "⌫";
    padding-right: .4em
}

.md-typeset .keys .key-backtab:before {
    content: "⇤";
    padding-right: .4em
}

.md-typeset .keys .key-caps-lock:before {
    content: "⇪";
    padding-right: .4em
}

.md-typeset .keys .key-clear:before {
    content: "⌧";
    padding-right: .4em
}

.md-typeset .keys .key-context-menu:before {
    content: "☰";
    padding-right: .4em
}

.md-typeset .keys .key-delete:before {
    content: "⌦";
    padding-right: .4em
}

.md-typeset .keys .key-eject:before {
    content: "⏏";
    padding-right: .4em
}

.md-typeset .keys .key-end:before {
    content: "⤓";
    padding-right: .4em
}

.md-typeset .keys .key-escape:before {
    content: "⎋";
    padding-right: .4em
}

.md-typeset .keys .key-home:before {
    content: "⤒";
    padding-right: .4em
}

.md-typeset .keys .key-insert:before {
    content: "⎀";
    padding-right: .4em
}

.md-typeset .keys .key-page-down:before {
    content: "⇟";
    padding-right: .4em
}

.md-typeset .keys .key-page-up:before {
    content: "⇞";
    padding-right: .4em
}

.md-typeset .keys .key-print-screen:before {
    content: "⎙";
    padding-right: .4em
}

.md-typeset .keys .key-tab:after {
    content: "⇥";
    padding-left: .4em
}

.md-typeset .keys .key-num-enter:after {
    content: "⌤";
    padding-left: .4em
}

.md-typeset .keys .key-enter:after {
    content: "⏎";
    padding-left: .4em
}

:root {
    --md-tabbed-icon--prev: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M15.41 16.58 10.83 12l4.58-4.59L14 6l-6 6 6 6 1.41-1.42Z"/></svg>');
    --md-tabbed-icon--next: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M8.59 16.58 13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.42Z"/></svg>')
}

.md-typeset .tabbed-set {
    border-radius: 0.125rem;
    display: flex;
    flex-flow: column wrap;
    margin: 1em 0;
    position: relative
}

.md-typeset .tabbed-set>input {
    height: 0;
    opacity: 0;
    position: absolute;
    width: 0
}

.md-typeset .tabbed-set>input:target {
    --md-scroll-offset: 0.625em
}

.md-typeset .tabbed-labels {
    -ms-overflow-style: none;
    box-shadow: 0 -0.0625rem var(--md-default-fg-color--lightest) inset;
    display: flex;
    max-width: 100%;
    overflow: auto;
    scrollbar-width: none
}

@media print {
    .md-typeset .tabbed-labels {
        display: contents
    }
}

@media screen {
    .js .md-typeset .tabbed-labels {
        position: relative
    }

    .js .md-typeset .tabbed-labels:before {
        background: var(--md-accent-fg-color);
        bottom: 0;
        content: "";
        display: block;
        height: 2px;
        left: 0;
        position: absolute;
        transform: translateX(var(--md-indicator-x));
        transition: width 225ms,transform .25s;
        transition-timing-function: cubic-bezier(.4,0,.2,1);
        width: var(--md-indicator-width)
    }
}

.md-typeset .tabbed-labels::-webkit-scrollbar {
    display: none
}

.md-typeset .tabbed-labels>label {
    border-bottom: 0.125rem solid #0000;
    border-radius: 0.125rem 0.125rem 0 0;
    color: var(--md-default-fg-color--light);
    cursor: pointer;
    flex-shrink: 0;
    font-size: 0.8rem;
    font-weight: 700;
    padding: .78125em 1.25em .625em;
    scroll-margin-inline-start: 1.25rem;
    transition: background-color .25s,color .25s;
    white-space: nowrap;
    width: auto
}

@media print {
    .md-typeset .tabbed-labels>label:first-child {
        order: 1
    }

    .md-typeset .tabbed-labels>label:nth-child(2) {
        order: 2
    }

    .md-typeset .tabbed-labels>label:nth-child(3) {
        order: 3
    }

    .md-typeset .tabbed-labels>label:nth-child(4) {
        order: 4
    }

    .md-typeset .tabbed-labels>label:nth-child(5) {
        order: 5
    }

    .md-typeset .tabbed-labels>label:nth-child(6) {
        order: 6
    }

    .md-typeset .tabbed-labels>label:nth-child(7) {
        order: 7
    }

    .md-typeset .tabbed-labels>label:nth-child(8) {
        order: 8
    }

    .md-typeset .tabbed-labels>label:nth-child(9) {
        order: 9
    }

    .md-typeset .tabbed-labels>label:nth-child(10) {
        order: 10
    }

    .md-typeset .tabbed-labels>label:nth-child(11) {
        order: 11
    }

    .md-typeset .tabbed-labels>label:nth-child(12) {
        order: 12
    }

    .md-typeset .tabbed-labels>label:nth-child(13) {
        order: 13
    }

    .md-typeset .tabbed-labels>label:nth-child(14) {
        order: 14
    }

    .md-typeset .tabbed-labels>label:nth-child(15) {
        order: 15
    }

    .md-typeset .tabbed-labels>label:nth-child(16) {
        order: 16
    }

    .md-typeset .tabbed-labels>label:nth-child(17) {
        order: 17
    }

    .md-typeset .tabbed-labels>label:nth-child(18) {
        order: 18
    }

    .md-typeset .tabbed-labels>label:nth-child(19) {
        order: 19
    }

    .md-typeset .tabbed-labels>label:nth-child(20) {
        order: 20
    }
}

.md-typeset .tabbed-labels>label:hover {
    color: var(--md-accent-fg-color)
}

.md-typeset .tabbed-content {
    width: 100%
}

@media print {
    .md-typeset .tabbed-content {
        display: contents
    }
}

.md-typeset .tabbed-block {
    display: none
}

@media print {
    .md-typeset .tabbed-block {
        display: block
    }

    .md-typeset .tabbed-block:first-child {
        order: 1
    }

    .md-typeset .tabbed-block:nth-child(2) {
        order: 2
    }

    .md-typeset .tabbed-block:nth-child(3) {
        order: 3
    }

    .md-typeset .tabbed-block:nth-child(4) {
        order: 4
    }

    .md-typeset .tabbed-block:nth-child(5) {
        order: 5
    }

    .md-typeset .tabbed-block:nth-child(6) {
        order: 6
    }

    .md-typeset .tabbed-block:nth-child(7) {
        order: 7
    }

    .md-typeset .tabbed-block:nth-child(8) {
        order: 8
    }

    .md-typeset .tabbed-block:nth-child(9) {
        order: 9
    }

    .md-typeset .tabbed-block:nth-child(10) {
        order: 10
    }

    .md-typeset .tabbed-block:nth-child(11) {
        order: 11
    }

    .md-typeset .tabbed-block:nth-child(12) {
        order: 12
    }

    .md-typeset .tabbed-block:nth-child(13) {
        order: 13
    }

    .md-typeset .tabbed-block:nth-child(14) {
        order: 14
    }

    .md-typeset .tabbed-block:nth-child(15) {
        order: 15
    }

    .md-typeset .tabbed-block:nth-child(16) {
        order: 16
    }

    .md-typeset .tabbed-block:nth-child(17) {
        order: 17
    }

    .md-typeset .tabbed-block:nth-child(18) {
        order: 18
    }

    .md-typeset .tabbed-block:nth-child(19) {
        order: 19
    }

    .md-typeset .tabbed-block:nth-child(20) {
        order: 20
    }
}

.md-typeset .tabbed-block>.highlight:first-child>pre,.md-typeset .tabbed-block>pre:first-child {
    margin: 0
}

.md-typeset .tabbed-block>.highlight:first-child>pre>code,.md-typeset .tabbed-block>pre:first-child>code {
    border-top-left-radius: 0;
    border-top-right-radius: 0
}

.md-typeset .tabbed-block>.highlight:first-child>.filename {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    margin: 0
}

.md-typeset .tabbed-block>.highlight:first-child>.highlighttable {
    margin: 0
}

.md-typeset .tabbed-block>.highlight:first-child>.highlighttable>tbody>tr>.filename span.filename,.md-typeset .tabbed-block>.highlight:first-child>.highlighttable>tbody>tr>.linenos {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    margin: 0
}

.md-typeset .tabbed-block>.highlight:first-child>.highlighttable>tbody>tr>.code>div>pre>code {
    border-top-left-radius: 0;
    border-top-right-radius: 0
}

.md-typeset .tabbed-block>.highlight:first-child+.result {
    margin-top: -.125em
}

.md-typeset .tabbed-block>.tabbed-set {
    margin: 0
}

.md-typeset .tabbed-button {
    align-self: center;
    border-radius: 100%;
    color: var(--md-default-fg-color--light);
    cursor: pointer;
    display: block;
    height: 1.125rem;
    margin-top: 0.125rem;
    pointer-events: auto;
    transition: background-color .25s;
    width: 1.125rem
}

.md-typeset .tabbed-button:hover {
    background-color: var(--md-accent-fg-color--transparent);
    color: var(--md-accent-fg-color)
}

.md-typeset .tabbed-button:after {
    background-color: currentcolor;
    content: "";
    display: block;
    height: 100%;
    -webkit-mask-image: var(--md-tabbed-icon--prev);
    mask-image: var(--md-tabbed-icon--prev);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    transition: background-color .25s,transform .25s;
    width: 100%
}

.md-typeset .tabbed-control {
    background: linear-gradient(to right,var(--md-default-bg-color) 60%,#0000);
    display: flex;
    height: 2.375rem;
    justify-content: start;
    pointer-events: none;
    position: absolute;
    transition: opacity 125ms;
    width: 1.5rem
}

[dir=rtl] .md-typeset .tabbed-control {
    transform: rotate(180deg)
}

.md-typeset .tabbed-control[hidden] {
    opacity: 0
}

.md-typeset .tabbed-control--next {
    background: linear-gradient(to left,var(--md-default-bg-color) 60%,#0000);
    justify-content: end;
    right: 0
}

.md-typeset .tabbed-control--next .tabbed-button:after {
    -webkit-mask-image: var(--md-tabbed-icon--next);
    mask-image: var(--md-tabbed-icon--next)
}

@media screen and (max-width: 44.9375em) {
    [dir=ltr] .md-content__inner>.tabbed-set .tabbed-labels {
        padding-left:1rem
    }

    [dir=rtl] .md-content__inner>.tabbed-set .tabbed-labels {
        padding-right: 1rem
    }

    .md-content__inner>.tabbed-set .tabbed-labels {
        margin: 0 -1rem;
        max-width: 100vw;
        scroll-padding-inline-start: 1rem
    }

    [dir=ltr] .md-content__inner>.tabbed-set .tabbed-labels:after {
        padding-right: 1rem
    }

    [dir=rtl] .md-content__inner>.tabbed-set .tabbed-labels:after {
        padding-left: 1rem
    }

    .md-content__inner>.tabbed-set .tabbed-labels:after {
        content: ""
    }

    [dir=ltr] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev {
        padding-left: 1rem
    }

    [dir=rtl] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev {
        padding-right: 1rem
    }

    [dir=ltr] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev {
        margin-left: -1rem
    }

    [dir=rtl] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev {
        margin-right: -1rem
    }

    .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev {
        width: 2.5rem
    }

    [dir=ltr] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next {
        padding-right: 1rem
    }

    [dir=rtl] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next {
        padding-left: 1rem
    }

    [dir=ltr] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next {
        margin-right: -1rem
    }

    [dir=rtl] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next {
        margin-left: -1rem
    }

    .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next {
        width: 2.5rem
    }
}

@media screen {
    .md-typeset .tabbed-set>input:first-child:checked~.tabbed-labels>:first-child,.md-typeset .tabbed-set>input:nth-child(10):checked~.tabbed-labels>:nth-child(10),.md-typeset .tabbed-set>input:nth-child(11):checked~.tabbed-labels>:nth-child(11),.md-typeset .tabbed-set>input:nth-child(12):checked~.tabbed-labels>:nth-child(12),.md-typeset .tabbed-set>input:nth-child(13):checked~.tabbed-labels>:nth-child(13),.md-typeset .tabbed-set>input:nth-child(14):checked~.tabbed-labels>:nth-child(14),.md-typeset .tabbed-set>input:nth-child(15):checked~.tabbed-labels>:nth-child(15),.md-typeset .tabbed-set>input:nth-child(16):checked~.tabbed-labels>:nth-child(16),.md-typeset .tabbed-set>input:nth-child(17):checked~.tabbed-labels>:nth-child(17),.md-typeset .tabbed-set>input:nth-child(18):checked~.tabbed-labels>:nth-child(18),.md-typeset .tabbed-set>input:nth-child(19):checked~.tabbed-labels>:nth-child(19),.md-typeset .tabbed-set>input:nth-child(2):checked~.tabbed-labels>:nth-child(2),.md-typeset .tabbed-set>input:nth-child(20):checked~.tabbed-labels>:nth-child(20),.md-typeset .tabbed-set>input:nth-child(3):checked~.tabbed-labels>:nth-child(3),.md-typeset .tabbed-set>input:nth-child(4):checked~.tabbed-labels>:nth-child(4),.md-typeset .tabbed-set>input:nth-child(5):checked~.tabbed-labels>:nth-child(5),.md-typeset .tabbed-set>input:nth-child(6):checked~.tabbed-labels>:nth-child(6),.md-typeset .tabbed-set>input:nth-child(7):checked~.tabbed-labels>:nth-child(7),.md-typeset .tabbed-set>input:nth-child(8):checked~.tabbed-labels>:nth-child(8),.md-typeset .tabbed-set>input:nth-child(9):checked~.tabbed-labels>:nth-child(9) {
        color: var(--md-accent-fg-color)
    }

    .md-typeset .no-js .tabbed-set>input:first-child:checked~.tabbed-labels>:first-child,.md-typeset .no-js .tabbed-set>input:nth-child(10):checked~.tabbed-labels>:nth-child(10),.md-typeset .no-js .tabbed-set>input:nth-child(11):checked~.tabbed-labels>:nth-child(11),.md-typeset .no-js .tabbed-set>input:nth-child(12):checked~.tabbed-labels>:nth-child(12),.md-typeset .no-js .tabbed-set>input:nth-child(13):checked~.tabbed-labels>:nth-child(13),.md-typeset .no-js .tabbed-set>input:nth-child(14):checked~.tabbed-labels>:nth-child(14),.md-typeset .no-js .tabbed-set>input:nth-child(15):checked~.tabbed-labels>:nth-child(15),.md-typeset .no-js .tabbed-set>input:nth-child(16):checked~.tabbed-labels>:nth-child(16),.md-typeset .no-js .tabbed-set>input:nth-child(17):checked~.tabbed-labels>:nth-child(17),.md-typeset .no-js .tabbed-set>input:nth-child(18):checked~.tabbed-labels>:nth-child(18),.md-typeset .no-js .tabbed-set>input:nth-child(19):checked~.tabbed-labels>:nth-child(19),.md-typeset .no-js .tabbed-set>input:nth-child(2):checked~.tabbed-labels>:nth-child(2),.md-typeset .no-js .tabbed-set>input:nth-child(20):checked~.tabbed-labels>:nth-child(20),.md-typeset .no-js .tabbed-set>input:nth-child(3):checked~.tabbed-labels>:nth-child(3),.md-typeset .no-js .tabbed-set>input:nth-child(4):checked~.tabbed-labels>:nth-child(4),.md-typeset .no-js .tabbed-set>input:nth-child(5):checked~.tabbed-labels>:nth-child(5),.md-typeset .no-js .tabbed-set>input:nth-child(6):checked~.tabbed-labels>:nth-child(6),.md-typeset .no-js .tabbed-set>input:nth-child(7):checked~.tabbed-labels>:nth-child(7),.md-typeset .no-js .tabbed-set>input:nth-child(8):checked~.tabbed-labels>:nth-child(8),.md-typeset .no-js .tabbed-set>input:nth-child(9):checked~.tabbed-labels>:nth-child(9),.no-js .md-typeset .tabbed-set>input:first-child:checked~.tabbed-labels>:first-child,.no-js .md-typeset .tabbed-set>input:nth-child(10):checked~.tabbed-labels>:nth-child(10),.no-js .md-typeset .tabbed-set>input:nth-child(11):checked~.tabbed-labels>:nth-child(11),.no-js .md-typeset .tabbed-set>input:nth-child(12):checked~.tabbed-labels>:nth-child(12),.no-js .md-typeset .tabbed-set>input:nth-child(13):checked~.tabbed-labels>:nth-child(13),.no-js .md-typeset .tabbed-set>input:nth-child(14):checked~.tabbed-labels>:nth-child(14),.no-js .md-typeset .tabbed-set>input:nth-child(15):checked~.tabbed-labels>:nth-child(15),.no-js .md-typeset .tabbed-set>input:nth-child(16):checked~.tabbed-labels>:nth-child(16),.no-js .md-typeset .tabbed-set>input:nth-child(17):checked~.tabbed-labels>:nth-child(17),.no-js .md-typeset .tabbed-set>input:nth-child(18):checked~.tabbed-labels>:nth-child(18),.no-js .md-typeset .tabbed-set>input:nth-child(19):checked~.tabbed-labels>:nth-child(19),.no-js .md-typeset .tabbed-set>input:nth-child(2):checked~.tabbed-labels>:nth-child(2),.no-js .md-typeset .tabbed-set>input:nth-child(20):checked~.tabbed-labels>:nth-child(20),.no-js .md-typeset .tabbed-set>input:nth-child(3):checked~.tabbed-labels>:nth-child(3),.no-js .md-typeset .tabbed-set>input:nth-child(4):checked~.tabbed-labels>:nth-child(4),.no-js .md-typeset .tabbed-set>input:nth-child(5):checked~.tabbed-labels>:nth-child(5),.no-js .md-typeset .tabbed-set>input:nth-child(6):checked~.tabbed-labels>:nth-child(6),.no-js .md-typeset .tabbed-set>input:nth-child(7):checked~.tabbed-labels>:nth-child(7),.no-js .md-typeset .tabbed-set>input:nth-child(8):checked~.tabbed-labels>:nth-child(8),.no-js .md-typeset .tabbed-set>input:nth-child(9):checked~.tabbed-labels>:nth-child(9) {
        border-color: var(--md-accent-fg-color)
    }
}

.md-typeset .tabbed-set>input:first-child.focus-visible~.tabbed-labels>:first-child,.md-typeset .tabbed-set>input:nth-child(10).focus-visible~.tabbed-labels>:nth-child(10),.md-typeset .tabbed-set>input:nth-child(11).focus-visible~.tabbed-labels>:nth-child(11),.md-typeset .tabbed-set>input:nth-child(12).focus-visible~.tabbed-labels>:nth-child(12),.md-typeset .tabbed-set>input:nth-child(13).focus-visible~.tabbed-labels>:nth-child(13),.md-typeset .tabbed-set>input:nth-child(14).focus-visible~.tabbed-labels>:nth-child(14),.md-typeset .tabbed-set>input:nth-child(15).focus-visible~.tabbed-labels>:nth-child(15),.md-typeset .tabbed-set>input:nth-child(16).focus-visible~.tabbed-labels>:nth-child(16),.md-typeset .tabbed-set>input:nth-child(17).focus-visible~.tabbed-labels>:nth-child(17),.md-typeset .tabbed-set>input:nth-child(18).focus-visible~.tabbed-labels>:nth-child(18),.md-typeset .tabbed-set>input:nth-child(19).focus-visible~.tabbed-labels>:nth-child(19),.md-typeset .tabbed-set>input:nth-child(2).focus-visible~.tabbed-labels>:nth-child(2),.md-typeset .tabbed-set>input:nth-child(20).focus-visible~.tabbed-labels>:nth-child(20),.md-typeset .tabbed-set>input:nth-child(3).focus-visible~.tabbed-labels>:nth-child(3),.md-typeset .tabbed-set>input:nth-child(4).focus-visible~.tabbed-labels>:nth-child(4),.md-typeset .tabbed-set>input:nth-child(5).focus-visible~.tabbed-labels>:nth-child(5),.md-typeset .tabbed-set>input:nth-child(6).focus-visible~.tabbed-labels>:nth-child(6),.md-typeset .tabbed-set>input:nth-child(7).focus-visible~.tabbed-labels>:nth-child(7),.md-typeset .tabbed-set>input:nth-child(8).focus-visible~.tabbed-labels>:nth-child(8),.md-typeset .tabbed-set>input:nth-child(9).focus-visible~.tabbed-labels>:nth-child(9) {
    background-color: var(--md-accent-fg-color--transparent)
}

.md-typeset .tabbed-set>input:first-child:checked~.tabbed-content>:first-child,.md-typeset .tabbed-set>input:nth-child(10):checked~.tabbed-content>:nth-child(10),.md-typeset .tabbed-set>input:nth-child(11):checked~.tabbed-content>:nth-child(11),.md-typeset .tabbed-set>input:nth-child(12):checked~.tabbed-content>:nth-child(12),.md-typeset .tabbed-set>input:nth-child(13):checked~.tabbed-content>:nth-child(13),.md-typeset .tabbed-set>input:nth-child(14):checked~.tabbed-content>:nth-child(14),.md-typeset .tabbed-set>input:nth-child(15):checked~.tabbed-content>:nth-child(15),.md-typeset .tabbed-set>input:nth-child(16):checked~.tabbed-content>:nth-child(16),.md-typeset .tabbed-set>input:nth-child(17):checked~.tabbed-content>:nth-child(17),.md-typeset .tabbed-set>input:nth-child(18):checked~.tabbed-content>:nth-child(18),.md-typeset .tabbed-set>input:nth-child(19):checked~.tabbed-content>:nth-child(19),.md-typeset .tabbed-set>input:nth-child(2):checked~.tabbed-content>:nth-child(2),.md-typeset .tabbed-set>input:nth-child(20):checked~.tabbed-content>:nth-child(20),.md-typeset .tabbed-set>input:nth-child(3):checked~.tabbed-content>:nth-child(3),.md-typeset .tabbed-set>input:nth-child(4):checked~.tabbed-content>:nth-child(4),.md-typeset .tabbed-set>input:nth-child(5):checked~.tabbed-content>:nth-child(5),.md-typeset .tabbed-set>input:nth-child(6):checked~.tabbed-content>:nth-child(6),.md-typeset .tabbed-set>input:nth-child(7):checked~.tabbed-content>:nth-child(7),.md-typeset .tabbed-set>input:nth-child(8):checked~.tabbed-content>:nth-child(8),.md-typeset .tabbed-set>input:nth-child(9):checked~.tabbed-content>:nth-child(9) {
    display: block
}

:root {
    --md-tasklist-icon: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M1 12C1 5.925 5.925 1 12 1s11 4.925 11 11-4.925 11-11 11S1 18.075 1 12Zm16.28-2.72a.751.751 0 0 0-.018-1.042.751.751 0 0 0-1.042-.018l-5.97 5.97-2.47-2.47a.751.751 0 0 0-1.042.018.751.751 0 0 0-.018 1.042l3 3a.75.75 0 0 0 1.06 0Z"/></svg>');
    --md-tasklist-icon--checked: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M1 12C1 5.925 5.925 1 12 1s11 4.925 11 11-4.925 11-11 11S1 18.075 1 12Zm16.28-2.72a.751.751 0 0 0-.018-1.042.751.751 0 0 0-1.042-.018l-5.97 5.97-2.47-2.47a.751.751 0 0 0-1.042.018.751.751 0 0 0-.018 1.042l3 3a.75.75 0 0 0 1.06 0Z"/></svg>')
}

.md-typeset .task-list-item {
    list-style-type: none;
    position: relative
}

[dir=ltr] .md-typeset .task-list-item [type=checkbox] {
    left: -2em
}

[dir=rtl] .md-typeset .task-list-item [type=checkbox] {
    right: -2em
}

.md-typeset .task-list-item [type=checkbox] {
    position: absolute;
    top: .45em
}

.md-typeset .task-list-control [type=checkbox] {
    opacity: 0;
    z-index: -1
}

[dir=ltr] .md-typeset .task-list-indicator:before {
    left: -1.5em
}

[dir=rtl] .md-typeset .task-list-indicator:before {
    right: -1.5em
}

.md-typeset .task-list-indicator:before {
    background-color: var(--md-default-fg-color--lightest);
    content: "";
    height: 1.25em;
    -webkit-mask-image: var(--md-tasklist-icon);
    mask-image: var(--md-tasklist-icon);
    -webkit-mask-position: center;
    mask-position: center;
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: contain;
    mask-size: contain;
    position: absolute;
    top: .15em;
    width: 1.25em
}

.md-typeset [type=checkbox]:checked+.task-list-indicator:before {
    background-color: #00e676;
    -webkit-mask-image: var(--md-tasklist-icon--checked);
    mask-image: var(--md-tasklist-icon--checked)
}

:root>* {
    --md-mermaid-font-family: var(--md-text-font-family),sans-serif;
    --md-mermaid-edge-color: var(--md-code-fg-color);
    --md-mermaid-node-bg-color: var(--md-accent-fg-color--transparent);
    --md-mermaid-node-fg-color: var(--md-accent-fg-color);
    --md-mermaid-label-bg-color: var(--md-default-bg-color);
    --md-mermaid-label-fg-color: var(--md-code-fg-color);
    --md-mermaid-sequence-actor-bg-color: var(--md-mermaid-label-bg-color);
    --md-mermaid-sequence-actor-fg-color: var(--md-mermaid-label-fg-color);
    --md-mermaid-sequence-actor-border-color: var(--md-mermaid-node-fg-color);
    --md-mermaid-sequence-actor-line-color: var(--md-default-fg-color--lighter);
    --md-mermaid-sequence-actorman-bg-color: var(--md-mermaid-label-bg-color);
    --md-mermaid-sequence-actorman-line-color: var(--md-mermaid-node-fg-color);
    --md-mermaid-sequence-box-bg-color: var(--md-mermaid-node-bg-color);
    --md-mermaid-sequence-box-fg-color: var(--md-mermaid-edge-color);
    --md-mermaid-sequence-label-bg-color: var(--md-mermaid-node-bg-color);
    --md-mermaid-sequence-label-fg-color: var(--md-mermaid-node-fg-color);
    --md-mermaid-sequence-loop-bg-color: var(--md-mermaid-node-bg-color);
    --md-mermaid-sequence-loop-fg-color: var(--md-mermaid-edge-color);
    --md-mermaid-sequence-loop-border-color: var(--md-mermaid-node-fg-color);
    --md-mermaid-sequence-message-fg-color: var(--md-mermaid-edge-color);
    --md-mermaid-sequence-message-line-color: var(--md-mermaid-edge-color);
    --md-mermaid-sequence-note-bg-color: var(--md-mermaid-label-bg-color);
    --md-mermaid-sequence-note-fg-color: var(--md-mermaid-edge-color);
    --md-mermaid-sequence-note-border-color: var(--md-mermaid-label-fg-color);
    --md-mermaid-sequence-number-bg-color: var(--md-mermaid-node-fg-color);
    --md-mermaid-sequence-number-fg-color: var(--md-accent-bg-color)
}

.mermaid {
    line-height: normal;
    margin: 1em 0
}

@media screen and (min-width: 45em) {
    [dir=ltr] .md-typeset .inline {
        float:left
    }

    [dir=rtl] .md-typeset .inline {
        float: right
    }

    [dir=ltr] .md-typeset .inline {
        margin-right: 1rem
    }

    [dir=rtl] .md-typeset .inline {
        margin-left: 1rem
    }

    .md-typeset .inline {
        margin-bottom: 1rem;
        margin-top: 0;
        width: 14.625rem
    }

    [dir=ltr] .md-typeset .inline.end {
        float: right
    }

    [dir=rtl] .md-typeset .inline.end {
        float: left
    }

    [dir=ltr] .md-typeset .inline.end {
        margin-left: 1rem;
        margin-right: 0
    }

    [dir=rtl] .md-typeset .inline.end {
        margin-left: 0;
        margin-right: 1rem
    }
}
